summaryrefslogtreecommitdiffstats
path: root/interfaces/ktexteditor
diff options
context:
space:
mode:
Diffstat (limited to 'interfaces/ktexteditor')
-rw-r--r--interfaces/ktexteditor/blockselectiondcopinterface.h4
-rw-r--r--interfaces/ktexteditor/blockselectioninterface.cpp4
-rw-r--r--interfaces/ktexteditor/blockselectioninterface.h2
-rw-r--r--interfaces/ktexteditor/clipboarddcopinterface.h4
-rw-r--r--interfaces/ktexteditor/clipboardinterface.cpp4
-rw-r--r--interfaces/ktexteditor/clipboardinterface.h2
-rw-r--r--interfaces/ktexteditor/codecompletioninterface.cpp2
-rw-r--r--interfaces/ktexteditor/codecompletioninterface.h24
-rw-r--r--interfaces/ktexteditor/configinterface.cpp2
-rw-r--r--interfaces/ktexteditor/configinterface.h2
-rw-r--r--interfaces/ktexteditor/configinterfaceextension.cpp4
-rw-r--r--interfaces/ktexteditor/configinterfaceextension.h16
-rw-r--r--interfaces/ktexteditor/cursorinterface.cpp2
-rw-r--r--interfaces/ktexteditor/cursorinterface.h12
-rw-r--r--interfaces/ktexteditor/document.h10
-rw-r--r--interfaces/ktexteditor/documentdcopinfo.cpp4
-rw-r--r--interfaces/ktexteditor/documentdcopinfo.h8
-rw-r--r--interfaces/ktexteditor/documentinfo.cpp4
-rw-r--r--interfaces/ktexteditor/documentinfo.h6
-rw-r--r--interfaces/ktexteditor/dynwordwrapinterface.cpp2
-rw-r--r--interfaces/ktexteditor/dynwordwrapinterface.h2
-rw-r--r--interfaces/ktexteditor/editdcopinterface.cpp10
-rw-r--r--interfaces/ktexteditor/editdcopinterface.h14
-rw-r--r--interfaces/ktexteditor/editinterface.cpp4
-rw-r--r--interfaces/ktexteditor/editinterface.h18
-rw-r--r--interfaces/ktexteditor/editinterfaceext.h2
-rw-r--r--interfaces/ktexteditor/editor.h4
-rw-r--r--interfaces/ktexteditor/editorchooser.cpp46
-rw-r--r--interfaces/ktexteditor/editorchooser.h24
-rw-r--r--interfaces/ktexteditor/encodingdcopinterface.cpp4
-rw-r--r--interfaces/ktexteditor/encodingdcopinterface.h8
-rw-r--r--interfaces/ktexteditor/encodinginterface.cpp4
-rw-r--r--interfaces/ktexteditor/encodinginterface.h6
-rw-r--r--interfaces/ktexteditor/highlightinginterface.cpp2
-rw-r--r--interfaces/ktexteditor/highlightinginterface.h6
-rw-r--r--interfaces/ktexteditor/ktexteditor.cpp20
-rw-r--r--interfaces/ktexteditor/markinterface.cpp2
-rw-r--r--interfaces/ktexteditor/markinterface.h6
-rw-r--r--interfaces/ktexteditor/markinterfaceextension.cpp2
-rw-r--r--interfaces/ktexteditor/markinterfaceextension.h12
-rw-r--r--interfaces/ktexteditor/plugin.h2
-rw-r--r--interfaces/ktexteditor/popupmenuinterface.cpp2
-rw-r--r--interfaces/ktexteditor/popupmenuinterface.h4
-rw-r--r--interfaces/ktexteditor/printdcopinterface.h4
-rw-r--r--interfaces/ktexteditor/printinterface.cpp4
-rw-r--r--interfaces/ktexteditor/printinterface.h2
-rw-r--r--interfaces/ktexteditor/searchdcopinterface.cpp32
-rw-r--r--interfaces/ktexteditor/searchdcopinterface.h24
-rw-r--r--interfaces/ktexteditor/searchinterface.cpp4
-rw-r--r--interfaces/ktexteditor/searchinterface.h6
-rw-r--r--interfaces/ktexteditor/selectiondcopinterface.cpp4
-rw-r--r--interfaces/ktexteditor/selectiondcopinterface.h8
-rw-r--r--interfaces/ktexteditor/selectionextdcopinterface.h2
-rw-r--r--interfaces/ktexteditor/selectioninterface.cpp4
-rw-r--r--interfaces/ktexteditor/selectioninterface.h8
-rw-r--r--interfaces/ktexteditor/selectioninterfaceext.cpp4
-rw-r--r--interfaces/ktexteditor/selectioninterfaceext.h2
-rw-r--r--interfaces/ktexteditor/sessionconfiginterface.cpp2
-rw-r--r--interfaces/ktexteditor/sessionconfiginterface.h2
-rw-r--r--interfaces/ktexteditor/templateinterface.cpp34
-rw-r--r--interfaces/ktexteditor/templateinterface.h14
-rw-r--r--interfaces/ktexteditor/texthintinterface.h6
-rw-r--r--interfaces/ktexteditor/undodcopinterface.h4
-rw-r--r--interfaces/ktexteditor/undointerface.cpp4
-rw-r--r--interfaces/ktexteditor/undointerface.h2
-rw-r--r--interfaces/ktexteditor/variableinterface.h4
-rw-r--r--interfaces/ktexteditor/view.h8
-rw-r--r--interfaces/ktexteditor/viewcursordcopinterface.cpp4
-rw-r--r--interfaces/ktexteditor/viewcursordcopinterface.h6
-rw-r--r--interfaces/ktexteditor/viewcursorinterface.cpp4
-rw-r--r--interfaces/ktexteditor/viewcursorinterface.h4
-rw-r--r--interfaces/ktexteditor/viewstatusmsgdcopinterface.cpp4
-rw-r--r--interfaces/ktexteditor/viewstatusmsgdcopinterface.h6
-rw-r--r--interfaces/ktexteditor/viewstatusmsginterface.cpp6
-rw-r--r--interfaces/ktexteditor/viewstatusmsginterface.h4
-rw-r--r--interfaces/ktexteditor/wordwrapinterface.cpp2
-rw-r--r--interfaces/ktexteditor/wordwrapinterface.h2
77 files changed, 276 insertions, 276 deletions
diff --git a/interfaces/ktexteditor/blockselectiondcopinterface.h b/interfaces/ktexteditor/blockselectiondcopinterface.h
index 19fc950cb..4b74fd2a0 100644
--- a/interfaces/ktexteditor/blockselectiondcopinterface.h
+++ b/interfaces/ktexteditor/blockselectiondcopinterface.h
@@ -3,8 +3,8 @@
#include <dcopobject.h>
#include <dcopref.h>
-#include <qstringlist.h>
-#include <qcstring.h>
+#include <tqstringlist.h>
+#include <tqcstring.h>
namespace KTextEditor
{
diff --git a/interfaces/ktexteditor/blockselectioninterface.cpp b/interfaces/ktexteditor/blockselectioninterface.cpp
index 80e0c8570..c1af4a6ed 100644
--- a/interfaces/ktexteditor/blockselectioninterface.cpp
+++ b/interfaces/ktexteditor/blockselectioninterface.cpp
@@ -43,7 +43,7 @@ BlockSelectionInterface::BlockSelectionInterface()
{
globalBlockSelectionInterfaceNumber++;
myBlockSelectionInterfaceNumber = globalBlockSelectionInterfaceNumber++;
- QString name = "BlockSelectionInterface#" + QString::number(myBlockSelectionInterfaceNumber);
+ TQString name = "BlockSelectionInterface#" + TQString::number(myBlockSelectionInterfaceNumber);
d = new PrivateBlockSelectionInterface();
d->interface = new BlockSelectionDCOPInterface(this, name.latin1());
@@ -60,7 +60,7 @@ unsigned int BlockSelectionInterface::blockSelectionInterfaceNumber () const
return myBlockSelectionInterfaceNumber;
}
-void BlockSelectionInterface::setBlockSelectionInterfaceDCOPSuffix (const QCString &suffix)
+void BlockSelectionInterface::setBlockSelectionInterfaceDCOPSuffix (const TQCString &suffix)
{
d->interface->setObjId ("BlockSelectionInterface#"+suffix);
}
diff --git a/interfaces/ktexteditor/blockselectioninterface.h b/interfaces/ktexteditor/blockselectioninterface.h
index d5104208c..9940f0da4 100644
--- a/interfaces/ktexteditor/blockselectioninterface.h
+++ b/interfaces/ktexteditor/blockselectioninterface.h
@@ -42,7 +42,7 @@ class KTEXTEDITOR_EXPORT BlockSelectionInterface
unsigned int blockSelectionInterfaceNumber () const;
protected:
- void setBlockSelectionInterfaceDCOPSuffix (const QCString &suffix);
+ void setBlockSelectionInterfaceDCOPSuffix (const TQCString &suffix);
/**
* slots !!!
diff --git a/interfaces/ktexteditor/clipboarddcopinterface.h b/interfaces/ktexteditor/clipboarddcopinterface.h
index fe4c3d3c7..8104e9d4d 100644
--- a/interfaces/ktexteditor/clipboarddcopinterface.h
+++ b/interfaces/ktexteditor/clipboarddcopinterface.h
@@ -3,8 +3,8 @@
#include <dcopobject.h>
#include <dcopref.h>
-#include <qstringlist.h>
-#include <qcstring.h>
+#include <tqstringlist.h>
+#include <tqcstring.h>
namespace KTextEditor
{
diff --git a/interfaces/ktexteditor/clipboardinterface.cpp b/interfaces/ktexteditor/clipboardinterface.cpp
index 5d267841a..4401b29de 100644
--- a/interfaces/ktexteditor/clipboardinterface.cpp
+++ b/interfaces/ktexteditor/clipboardinterface.cpp
@@ -28,7 +28,7 @@ ClipboardInterface::ClipboardInterface()
d = new PrivateClipboardInterface();
globalClipboardInterfaceNumber++;
myClipboardInterfaceNumber = globalClipboardInterfaceNumber++;
- QString name = "ClipboardInterface#" + QString::number(myClipboardInterfaceNumber);
+ TQString name = "ClipboardInterface#" + TQString::number(myClipboardInterfaceNumber);
d->interface = new ClipboardDCOPInterface(this, name.latin1());
}
ClipboardInterface::~ClipboardInterface()
@@ -42,7 +42,7 @@ unsigned int ClipboardInterface::clipboardInterfaceNumber () const
return myClipboardInterfaceNumber;
}
-void ClipboardInterface::setClipboardInterfaceDCOPSuffix (const QCString &suffix)
+void ClipboardInterface::setClipboardInterfaceDCOPSuffix (const TQCString &suffix)
{
d->interface->setObjId ("ClipboardInterface#"+suffix);
}
diff --git a/interfaces/ktexteditor/clipboardinterface.h b/interfaces/ktexteditor/clipboardinterface.h
index c55df503e..3e1143240 100644
--- a/interfaces/ktexteditor/clipboardinterface.h
+++ b/interfaces/ktexteditor/clipboardinterface.h
@@ -40,7 +40,7 @@ class KTEXTEDITOR_EXPORT ClipboardInterface
unsigned int clipboardInterfaceNumber () const;
protected:
- void setClipboardInterfaceDCOPSuffix (const QCString &suffix);
+ void setClipboardInterfaceDCOPSuffix (const TQCString &suffix);
/**
* slots !!!
diff --git a/interfaces/ktexteditor/codecompletioninterface.cpp b/interfaces/ktexteditor/codecompletioninterface.cpp
index 51250d2d6..ae60b2162 100644
--- a/interfaces/ktexteditor/codecompletioninterface.cpp
+++ b/interfaces/ktexteditor/codecompletioninterface.cpp
@@ -35,7 +35,7 @@ unsigned int CodeCompletionInterface::codeCompletionInterfaceNumber () const
return myCodeCompletionInterfaceNumber;
}
-void CodeCompletionInterface::setCodeCompletionInterfaceDCOPSuffix (const QCString &/*suffix*/)
+void CodeCompletionInterface::setCodeCompletionInterfaceDCOPSuffix (const TQCString &/*suffix*/)
{
//d->interface->setObjId ("CodeCompletionInterface#"+suffix);
}
diff --git a/interfaces/ktexteditor/codecompletioninterface.h b/interfaces/ktexteditor/codecompletioninterface.h
index d1174d32a..780c02bbe 100644
--- a/interfaces/ktexteditor/codecompletioninterface.h
+++ b/interfaces/ktexteditor/codecompletioninterface.h
@@ -19,8 +19,8 @@
#ifndef __ktexteditor_codecompletioninterface_h__
#define __ktexteditor_codecompletioninterface_h__
-#include <qstring.h>
-#include <qstringlist.h>
+#include <tqstring.h>
+#include <tqstringlist.h>
#include <kdelibs_export.h>
@@ -42,13 +42,13 @@ namespace KTextEditor
class KTEXTEDITOR_EXPORT CompletionEntry
{
public:
- QString type;
- QString text;
- QString prefix;
- QString postfix;
- QString comment;
+ TQString type;
+ TQString text;
+ TQString prefix;
+ TQString postfix;
+ TQString comment;
- QString userdata;
+ TQString userdata;
bool operator==( const CompletionEntry &c ) const {
return ( c.type == type &&
@@ -94,7 +94,7 @@ class KTEXTEDITOR_EXPORT CodeCompletionInterface
unsigned int codeCompletionInterfaceNumber () const;
protected:
- void setCodeCompletionInterfaceDCOPSuffix (const QCString &suffix);
+ void setCodeCompletionInterfaceDCOPSuffix (const TQCString &suffix);
public:
@@ -104,7 +104,7 @@ class KTEXTEDITOR_EXPORT CodeCompletionInterface
/**
* This shows an argument hint.
*/
- virtual void showArgHint (QStringList functionList, const QString& strWrapping, const QString& strDelimiter) = 0;
+ virtual void showArgHint (TQStringList functionList, const TQString& strWrapping, const TQString& strDelimiter) = 0;
/**
* This shows a completion list. @p offset is the real start of the text that
@@ -112,7 +112,7 @@ class KTEXTEDITOR_EXPORT CodeCompletionInterface
* position. if @p casesensitive is @p true, the popup will only contain completions
* that match the input text regarding case.
*/
- virtual void showCompletionBox (QValueList<CompletionEntry> complList,int offset=0, bool casesensitive=true)=0;
+ virtual void showCompletionBox (TQValueList<CompletionEntry> complList,int offset=0, bool casesensitive=true)=0;
//
// signals !!!
@@ -186,7 +186,7 @@ class KTEXTEDITOR_EXPORT CodeCompletionInterface
* IMPORTANT FOR IMPLEMENTERS: When you don't support this signal, please just override the inherited
* function, if you support it, declare it as a signal
*/
- virtual void filterInsertString(CompletionEntry*,QString*)=0;
+ virtual void filterInsertString(CompletionEntry*,TQString*)=0;
private:
diff --git a/interfaces/ktexteditor/configinterface.cpp b/interfaces/ktexteditor/configinterface.cpp
index 39d2454ba..2ca2e4b12 100644
--- a/interfaces/ktexteditor/configinterface.cpp
+++ b/interfaces/ktexteditor/configinterface.cpp
@@ -57,7 +57,7 @@ unsigned int ConfigInterface::configInterfaceNumber () const
return myConfigInterfaceNumber;
}
-void ConfigInterface::setConfigInterfaceDCOPSuffix (const QCString &/*suffix*/)
+void ConfigInterface::setConfigInterfaceDCOPSuffix (const TQCString &/*suffix*/)
{
//d->interface->setObjId ("ConfigInterface#"+suffix);
}
diff --git a/interfaces/ktexteditor/configinterface.h b/interfaces/ktexteditor/configinterface.h
index f80603d01..5b89ff413 100644
--- a/interfaces/ktexteditor/configinterface.h
+++ b/interfaces/ktexteditor/configinterface.h
@@ -42,7 +42,7 @@ class KTEXTEDITOR_EXPORT ConfigInterface
unsigned int configInterfaceNumber () const;
protected:
- void setConfigInterfaceDCOPSuffix (const QCString &suffix);
+ void setConfigInterfaceDCOPSuffix (const TQCString &suffix);
//
// slots !!!
diff --git a/interfaces/ktexteditor/configinterfaceextension.cpp b/interfaces/ktexteditor/configinterfaceextension.cpp
index 9f7456cbe..8557c422f 100644
--- a/interfaces/ktexteditor/configinterfaceextension.cpp
+++ b/interfaces/ktexteditor/configinterfaceextension.cpp
@@ -38,7 +38,7 @@ class PrivateConfigInterfaceExtension
using namespace KTextEditor;
-ConfigPage::ConfigPage ( QWidget *parent, const char *name ) : QWidget (parent, name) { ; }
+ConfigPage::ConfigPage ( TQWidget *parent, const char *name ) : TQWidget (parent, name) { ; }
ConfigPage::~ConfigPage () { ; }
@@ -62,7 +62,7 @@ unsigned int ConfigInterfaceExtension::configInterfaceExtensionNumber () const
return myConfigInterfaceExtensionNumber;
}
-void ConfigInterfaceExtension::setConfigInterfaceExtensionDCOPSuffix (const QCString &/*suffix*/)
+void ConfigInterfaceExtension::setConfigInterfaceExtensionDCOPSuffix (const TQCString &/*suffix*/)
{
//d->interface->setObjId ("ConfigInterfaceExtension#"+suffix);
}
diff --git a/interfaces/ktexteditor/configinterfaceextension.h b/interfaces/ktexteditor/configinterfaceextension.h
index abec0f0fe..6ebfd8895 100644
--- a/interfaces/ktexteditor/configinterfaceextension.h
+++ b/interfaces/ktexteditor/configinterfaceextension.h
@@ -19,8 +19,8 @@
#ifndef __ktexteditor_configinterfaceextension_h__
#define __ktexteditor_configinterfaceextension_h__
-#include <qwidget.h>
-#include <qpixmap.h>
+#include <tqwidget.h>
+#include <tqpixmap.h>
#include <kicontheme.h>
namespace KTextEditor
@@ -31,7 +31,7 @@ class KTEXTEDITOR_EXPORT ConfigPage : public QWidget
Q_OBJECT
public:
- ConfigPage ( QWidget *parent=0, const char *name=0 );
+ ConfigPage ( TQWidget *parent=0, const char *name=0 );
virtual ~ConfigPage ();
//
@@ -75,7 +75,7 @@ class KTEXTEDITOR_EXPORT ConfigInterfaceExtension
unsigned int configInterfaceExtensionNumber () const;
protected:
- void setConfigInterfaceExtensionDCOPSuffix (const QCString &suffix);
+ void setConfigInterfaceExtensionDCOPSuffix (const TQCString &suffix);
//
// slots !!!
@@ -91,11 +91,11 @@ class KTEXTEDITOR_EXPORT ConfigInterfaceExtension
config pages from 0 to configPages()-1 are available
if configPages() > 0
*/
- virtual ConfigPage *configPage (uint number = 0, QWidget *parent = 0, const char *name=0 ) = 0;
+ virtual ConfigPage *configPage (uint number = 0, TQWidget *parent = 0, const char *name=0 ) = 0;
- virtual QString configPageName (uint number = 0) const = 0;
- virtual QString configPageFullName (uint number = 0) const = 0;
- virtual QPixmap configPagePixmap (uint number = 0, int size = KIcon::SizeSmall) const = 0;
+ virtual TQString configPageName (uint number = 0) const = 0;
+ virtual TQString configPageFullName (uint number = 0) const = 0;
+ virtual TQPixmap configPagePixmap (uint number = 0, int size = KIcon::SizeSmall) const = 0;
private:
diff --git a/interfaces/ktexteditor/cursorinterface.cpp b/interfaces/ktexteditor/cursorinterface.cpp
index 9dec0de30..91a14b06a 100644
--- a/interfaces/ktexteditor/cursorinterface.cpp
+++ b/interfaces/ktexteditor/cursorinterface.cpp
@@ -55,7 +55,7 @@ unsigned int CursorInterface::cursorInterfaceNumber () const
return myCursorInterfaceNumber;
}
-void CursorInterface::setCursorInterfaceDCOPSuffix (const QCString &/*suffix*/)
+void CursorInterface::setCursorInterfaceDCOPSuffix (const TQCString &/*suffix*/)
{
//d->interface->setObjId ("CursorInterface#"+suffix);
}
diff --git a/interfaces/ktexteditor/cursorinterface.h b/interfaces/ktexteditor/cursorinterface.h
index b243d3c4c..ad3e0134b 100644
--- a/interfaces/ktexteditor/cursorinterface.h
+++ b/interfaces/ktexteditor/cursorinterface.h
@@ -19,8 +19,8 @@
#ifndef __ktexteditor_cursorinterface_h__
#define __ktexteditor_cursorinterface_h__
-#include <qptrlist.h>
-#include <qstring.h>
+#include <tqptrlist.h>
+#include <tqstring.h>
#include <kdelibs_export.h>
@@ -37,11 +37,11 @@ class KTEXTEDITOR_EXPORT Cursor
virtual bool setPosition ( unsigned int line, unsigned int col ) = 0;
- virtual bool insertText ( const QString& text ) = 0;
+ virtual bool insertText ( const TQString& text ) = 0;
virtual bool removeText ( unsigned int numberOfCharacters ) = 0;
- virtual QChar currentChar () const = 0;
+ virtual TQChar currentChar () const = 0;
};
/**
@@ -58,7 +58,7 @@ class KTEXTEDITOR_EXPORT CursorInterface
unsigned int cursorInterfaceNumber () const;
protected:
- void setCursorInterfaceDCOPSuffix (const QCString &suffix);
+ void setCursorInterfaceDCOPSuffix (const TQCString &suffix);
public:
/**
@@ -69,7 +69,7 @@ class KTEXTEDITOR_EXPORT CursorInterface
/*
* Accessor to the list of cursors.
*/
- virtual QPtrList<Cursor> cursors () const = 0;
+ virtual TQPtrList<Cursor> cursors () const = 0;
private:
class PrivateCursorInterface *d;
diff --git a/interfaces/ktexteditor/document.h b/interfaces/ktexteditor/document.h
index 9260d596c..624c344b9 100644
--- a/interfaces/ktexteditor/document.h
+++ b/interfaces/ktexteditor/document.h
@@ -35,7 +35,7 @@ class KTEXTEDITOR_EXPORT Document : public KTextEditor::Editor
Q_OBJECT
public:
- Document ( QObject *parent = 0, const char *name = 0 );
+ Document ( TQObject *parent = 0, const char *name = 0 );
virtual ~Document ();
/**
@@ -46,19 +46,19 @@ class KTEXTEDITOR_EXPORT Document : public KTextEditor::Editor
/**
* Returns this document's DCOP suffix for identifiying its DCOP interface.
*/
- QCString documentDCOPSuffix () const;
+ TQCString documentDCOPSuffix () const;
/**
* Create a view that will display the document data. You can create as many
* views as you like. When the user modifies data in one view then all other
* views will be updated as well.
*/
- virtual class View *createView ( QWidget *parent, const char *name = 0 ) = 0;
+ virtual class View *createView ( TQWidget *parent, const char *name = 0 ) = 0;
/*
* Returns a list of all views of this document.
*/
- virtual QPtrList<class View> views () const = 0;
+ virtual TQPtrList<class View> views () const = 0;
private:
class PrivateDocument *d;
@@ -66,7 +66,7 @@ class KTEXTEDITOR_EXPORT Document : public KTextEditor::Editor
unsigned int myDocumentNumber;
};
-KTEXTEDITOR_EXPORT Document *createDocument ( const char* libname, QObject *parent = 0, const char *name = 0 );
+KTEXTEDITOR_EXPORT Document *createDocument ( const char* libname, TQObject *parent = 0, const char *name = 0 );
}
diff --git a/interfaces/ktexteditor/documentdcopinfo.cpp b/interfaces/ktexteditor/documentdcopinfo.cpp
index 7377fcf79..b339d01cd 100644
--- a/interfaces/ktexteditor/documentdcopinfo.cpp
+++ b/interfaces/ktexteditor/documentdcopinfo.cpp
@@ -15,7 +15,7 @@ DocumentInfoDCOPInterface::~DocumentInfoDCOPInterface()
}
-QString DocumentInfoDCOPInterface::mimeType()
+TQString DocumentInfoDCOPInterface::mimeType()
{
return m_parent->mimeType();
}
@@ -23,7 +23,7 @@ long DocumentInfoDCOPInterface::fileSize()
{
return m_parent->fileSize();
}
-QString DocumentInfoDCOPInterface::niceFileSize()
+TQString DocumentInfoDCOPInterface::niceFileSize()
{
return m_parent->niceFileSize();
}
diff --git a/interfaces/ktexteditor/documentdcopinfo.h b/interfaces/ktexteditor/documentdcopinfo.h
index 2293ff119..ea25284fe 100644
--- a/interfaces/ktexteditor/documentdcopinfo.h
+++ b/interfaces/ktexteditor/documentdcopinfo.h
@@ -3,8 +3,8 @@
#include <dcopobject.h>
#include <dcopref.h>
-#include <qstringlist.h>
-#include <qcstring.h>
+#include <tqstringlist.h>
+#include <tqcstring.h>
namespace KTextEditor
{
@@ -34,9 +34,9 @@ namespace KTextEditor
*/
virtual ~DocumentInfoDCOPInterface();
k_dcop:
- QString mimeType();
+ TQString mimeType();
long fileSize();
- QString niceFileSize();
+ TQString niceFileSize();
uint documentInfoInterfaceNumber ();
private:
DocumentInfoInterface *m_parent;
diff --git a/interfaces/ktexteditor/documentinfo.cpp b/interfaces/ktexteditor/documentinfo.cpp
index 0047b5454..c675bfb5f 100644
--- a/interfaces/ktexteditor/documentinfo.cpp
+++ b/interfaces/ktexteditor/documentinfo.cpp
@@ -44,7 +44,7 @@ DocumentInfoInterface::DocumentInfoInterface()
myDocumentInfoInterfaceNumber = globalDocumentInfoInterfaceNumber++;
d = new PrivateDocumentInfoInterface();
- QString name = "DocumentInterface#" + QString::number(myDocumentInfoInterfaceNumber);
+ TQString name = "DocumentInterface#" + TQString::number(myDocumentInfoInterfaceNumber);
d->interface = new DocumentInfoDCOPInterface(this, name.latin1());
}
@@ -59,7 +59,7 @@ unsigned int DocumentInfoInterface::documentInfoInterfaceNumber () const
return myDocumentInfoInterfaceNumber;
}
-void DocumentInfoInterface::setDocumentInfoInterfaceDCOPSuffix (const QCString &suffix)
+void DocumentInfoInterface::setDocumentInfoInterfaceDCOPSuffix (const TQCString &suffix)
{
d->interface->setObjId ("DocumentInfoInterface#"+suffix);
}
diff --git a/interfaces/ktexteditor/documentinfo.h b/interfaces/ktexteditor/documentinfo.h
index 9e6eb06e5..0832288de 100644
--- a/interfaces/ktexteditor/documentinfo.h
+++ b/interfaces/ktexteditor/documentinfo.h
@@ -39,14 +39,14 @@ class KTEXTEDITOR_EXPORT DocumentInfoInterface
DocumentInfoInterface();
virtual ~DocumentInfoInterface();
- virtual QString mimeType()=0;
+ virtual TQString mimeType()=0;
virtual long fileSize()=0;
- virtual QString niceFileSize()=0;
+ virtual TQString niceFileSize()=0;
unsigned int documentInfoInterfaceNumber () const;
protected:
- void setDocumentInfoInterfaceDCOPSuffix (const QCString &suffix);
+ void setDocumentInfoInterfaceDCOPSuffix (const TQCString &suffix);
private:
class PrivateDocumentInfoInterface *d;
diff --git a/interfaces/ktexteditor/dynwordwrapinterface.cpp b/interfaces/ktexteditor/dynwordwrapinterface.cpp
index e8448ed9c..49d4060c0 100644
--- a/interfaces/ktexteditor/dynwordwrapinterface.cpp
+++ b/interfaces/ktexteditor/dynwordwrapinterface.cpp
@@ -55,7 +55,7 @@ unsigned int DynWordWrapInterface::dynWordWrapInterfaceNumber () const
return myDynWordWrapInterfaceNumber;
}
-void DynWordWrapInterface::setDynWordWrapInterfaceDCOPSuffix (const QCString &/*suffix*/)
+void DynWordWrapInterface::setDynWordWrapInterfaceDCOPSuffix (const TQCString &/*suffix*/)
{
//d->interface->setObjId ("DynWordWrapInterface#"+suffix);
}
diff --git a/interfaces/ktexteditor/dynwordwrapinterface.h b/interfaces/ktexteditor/dynwordwrapinterface.h
index 165b4191d..2576ae6f0 100644
--- a/interfaces/ktexteditor/dynwordwrapinterface.h
+++ b/interfaces/ktexteditor/dynwordwrapinterface.h
@@ -42,7 +42,7 @@ class KTEXTEDITOR_EXPORT DynWordWrapInterface
unsigned int dynWordWrapInterfaceNumber () const;
protected:
- void setDynWordWrapInterfaceDCOPSuffix (const QCString &suffix);
+ void setDynWordWrapInterfaceDCOPSuffix (const TQCString &suffix);
//
// slots !!!
diff --git a/interfaces/ktexteditor/editdcopinterface.cpp b/interfaces/ktexteditor/editdcopinterface.cpp
index 1a002d775..6130ccd14 100644
--- a/interfaces/ktexteditor/editdcopinterface.cpp
+++ b/interfaces/ktexteditor/editdcopinterface.cpp
@@ -15,12 +15,12 @@ EditDCOPInterface::~EditDCOPInterface()
}
-QString EditDCOPInterface::text ()
+TQString EditDCOPInterface::text ()
{
return m_parent->text();
}
-QString EditDCOPInterface::textLine ( uint line )
+TQString EditDCOPInterface::textLine ( uint line )
{
return m_parent->textLine(line);
}
@@ -35,12 +35,12 @@ int EditDCOPInterface::length ()
return m_parent->length();
}
-void EditDCOPInterface::setText ( const QString &text )
+void EditDCOPInterface::setText ( const TQString &text )
{
m_parent->setText(text);
}
-bool EditDCOPInterface::insertText ( uint line, uint col, const QString &text )
+bool EditDCOPInterface::insertText ( uint line, uint col, const TQString &text )
{
return m_parent->insertText( line, col, text);
}
@@ -50,7 +50,7 @@ bool EditDCOPInterface::removeText ( uint startLine, uint startCol, uint endLine
return m_parent->removeText( startLine, startCol, endLine, endCol);
}
-bool EditDCOPInterface::insertLine ( uint line, const QString &text )
+bool EditDCOPInterface::insertLine ( uint line, const TQString &text )
{
return m_parent->insertLine( line, text);
}
diff --git a/interfaces/ktexteditor/editdcopinterface.h b/interfaces/ktexteditor/editdcopinterface.h
index b6956d5fa..f169fb15b 100644
--- a/interfaces/ktexteditor/editdcopinterface.h
+++ b/interfaces/ktexteditor/editdcopinterface.h
@@ -3,8 +3,8 @@
#include <dcopobject.h>
#include <dcopref.h>
-#include <qstringlist.h>
-#include <qcstring.h>
+#include <tqstringlist.h>
+#include <tqcstring.h>
//#include "editdcopinterface.moc"
namespace KTextEditor
{
@@ -36,12 +36,12 @@ namespace KTextEditor
/**
* @return the complete document as a single QString
*/
- virtual QString text ();
+ virtual TQString text ();
/**
* @return All the text from the requested line.
*/
- virtual QString textLine ( uint line );
+ virtual TQString textLine ( uint line );
/**
* @return The current number of lines in the document
@@ -57,13 +57,13 @@ namespace KTextEditor
* Set the given text into the view.
* Warning: This will overwrite any data currently held in this view.
*/
- virtual void setText (const QString &text );
+ virtual void setText (const TQString &text );
/**
* Inserts text at line "line", column "col"
* returns true if success
*/
- virtual bool insertText ( uint line, uint col, const QString &text );
+ virtual bool insertText ( uint line, uint col, const TQString &text );
/**
* remove text at line "line", column "col"
@@ -74,7 +74,7 @@ namespace KTextEditor
/**
* Insert line(s) at the given line number.
*/
- virtual bool insertLine ( uint line, const QString &text );
+ virtual bool insertLine ( uint line, const TQString &text );
/**
* Insert line(s) at the given line number.
diff --git a/interfaces/ktexteditor/editinterface.cpp b/interfaces/ktexteditor/editinterface.cpp
index 095c44ba9..6722fc555 100644
--- a/interfaces/ktexteditor/editinterface.cpp
+++ b/interfaces/ktexteditor/editinterface.cpp
@@ -27,7 +27,7 @@ EditInterface::EditInterface()
d = new PrivateEditInterface();
globalEditInterfaceNumber++;
myEditInterfaceNumber = globalEditInterfaceNumber;
- QString name = "EditInterface#" + QString::number(myEditInterfaceNumber);
+ TQString name = "EditInterface#" + TQString::number(myEditInterfaceNumber);
d->interface = new EditDCOPInterface(this, name.latin1());
}
@@ -42,7 +42,7 @@ uint EditInterface::editInterfaceNumber () const
return myEditInterfaceNumber;
}
-void EditInterface::setEditInterfaceDCOPSuffix (const QCString &suffix)
+void EditInterface::setEditInterfaceDCOPSuffix (const TQCString &suffix)
{
d->interface->setObjId ("EditInterface#"+suffix);
}
diff --git a/interfaces/ktexteditor/editinterface.h b/interfaces/ktexteditor/editinterface.h
index baea99803..a2f8f5fe6 100644
--- a/interfaces/ktexteditor/editinterface.h
+++ b/interfaces/ktexteditor/editinterface.h
@@ -19,7 +19,7 @@
#ifndef __ktexteditor_editinterface_h__
#define __ktexteditor_editinterface_h__
-#include <qstring.h>
+#include <tqstring.h>
#include <kdelibs_export.h>
@@ -41,7 +41,7 @@ class KTEXTEDITOR_EXPORT EditInterface
uint editInterfaceNumber () const;
protected:
- void setEditInterfaceDCOPSuffix (const QCString &suffix);
+ void setEditInterfaceDCOPSuffix (const TQCString &suffix);
public:
/**
@@ -50,17 +50,17 @@ class KTEXTEDITOR_EXPORT EditInterface
/**
* @return the complete document as a single QString
*/
- virtual QString text () const = 0;
+ virtual TQString text () const = 0;
/**
* @return a QString
*/
- virtual QString text ( uint startLine, uint startCol, uint endLine, uint endCol ) const = 0;
+ virtual TQString text ( uint startLine, uint startCol, uint endLine, uint endCol ) const = 0;
/**
* @return All the text from the requested line.
*/
- virtual QString textLine ( uint line ) const = 0;
+ virtual TQString textLine ( uint line ) const = 0;
/**
* @return The current number of lines in the document
@@ -81,7 +81,7 @@ class KTEXTEDITOR_EXPORT EditInterface
* Set the given text into the view.
* Warning: This will overwrite any data currently held in this view.
*/
- virtual bool setText ( const QString &text ) = 0;
+ virtual bool setText ( const TQString &text ) = 0;
/**
* clears the document
@@ -94,7 +94,7 @@ class KTEXTEDITOR_EXPORT EditInterface
* returns true if success
* Use insertText(numLines(), ...) to append text at end of document
*/
- virtual bool insertText ( uint line, uint col, const QString &text ) = 0;
+ virtual bool insertText ( uint line, uint col, const TQString &text ) = 0;
/**
* remove text at line "line", column "col"
@@ -106,7 +106,7 @@ class KTEXTEDITOR_EXPORT EditInterface
* Insert line(s) at the given line number.
* Use insertLine(numLines(), text) to append line at end of document
*/
- virtual bool insertLine ( uint line, const QString &text ) = 0;
+ virtual bool insertLine ( uint line, const TQString &text ) = 0;
/**
* Remove line(s) at the given line number.
@@ -119,7 +119,7 @@ class KTEXTEDITOR_EXPORT EditInterface
public:
virtual void textChanged () = 0;
- virtual void charactersInteractivelyInserted(int ,int ,const QString&)=0; //line, col, characters if you don't support this, don't create a signal, just overload it.
+ virtual void charactersInteractivelyInserted(int ,int ,const TQString&)=0; //line, col, characters if you don't support this, don't create a signal, just overload it.
/**
* only for the interface itself - REAL PRIVATE
diff --git a/interfaces/ktexteditor/editinterfaceext.h b/interfaces/ktexteditor/editinterfaceext.h
index f34ce80b9..650bb9ec2 100644
--- a/interfaces/ktexteditor/editinterfaceext.h
+++ b/interfaces/ktexteditor/editinterfaceext.h
@@ -20,7 +20,7 @@
#ifndef __ktexteditor_editinterfaceext_h__
#define __ktexteditor_editinterfaceext_h__
-#include <qstring.h>
+#include <tqstring.h>
#include <kdelibs_export.h>
diff --git a/interfaces/ktexteditor/editor.h b/interfaces/ktexteditor/editor.h
index 6f196d34e..11f9a8c15 100644
--- a/interfaces/ktexteditor/editor.h
+++ b/interfaces/ktexteditor/editor.h
@@ -46,7 +46,7 @@ class KTEXTEDITOR_EXPORT Editor : public KParts::ReadWritePart
/**
* Create a new editor widget.
*/
- Editor ( QObject *parent = 0, const char *name = 0 );
+ Editor ( TQObject *parent = 0, const char *name = 0 );
virtual ~Editor ();
unsigned int editorNumber () const;
@@ -57,7 +57,7 @@ class KTEXTEDITOR_EXPORT Editor : public KParts::ReadWritePart
unsigned int myEditorNumber;
};
-KTEXTEDITOR_EXPORT Editor *createEditor ( const char* libname, QWidget *parentWidget = 0, const char *widgetName = 0, QObject *parent = 0, const char *name = 0 );
+KTEXTEDITOR_EXPORT Editor *createEditor ( const char* libname, TQWidget *parentWidget = 0, const char *widgetName = 0, TQObject *parent = 0, const char *name = 0 );
}
diff --git a/interfaces/ktexteditor/editorchooser.cpp b/interfaces/ktexteditor/editorchooser.cpp
index a7211ab49..96cf3649e 100644
--- a/interfaces/ktexteditor/editorchooser.cpp
+++ b/interfaces/ktexteditor/editorchooser.cpp
@@ -1,15 +1,15 @@
#include <editorchooser.h>
#include <editorchooser.moc>
-#include <qcombobox.h>
+#include <tqcombobox.h>
#include <ktrader.h>
#include <kconfig.h>
-#include <qstringlist.h>
+#include <tqstringlist.h>
#include <kservice.h>
#include <klocale.h>
-#include <qlabel.h>
+#include <tqlabel.h>
#include <kapplication.h>
-#include <qlayout.h>
+#include <tqlayout.h>
#include "editorchooser_ui.h"
@@ -26,19 +26,19 @@ namespace KTextEditor
~PrivateEditorChooser(){}
// Data Members
EditorChooser_UI *chooser;
- QStringList ElementNames;
- QStringList elements;
+ TQStringList ElementNames;
+ TQStringList elements;
};
}
-EditorChooser::EditorChooser(QWidget *parent,const char *name) :
- QWidget (parent,name)
+EditorChooser::EditorChooser(TQWidget *parent,const char *name) :
+ TQWidget (parent,name)
{
d = new PrivateEditorChooser ();
// sizemanagment
- QGridLayout *grid = new QGridLayout( this, 1, 1 );
+ TQGridLayout *grid = new TQGridLayout( this, 1, 1 );
d->chooser = new EditorChooser_UI (this, name);
@@ -49,7 +49,7 @@ EditorChooser::EditorChooser(QWidget *parent,const char *name) :
KTrader::OfferList offers = KTrader::self()->query("text/plain", "'KTextEditor/Document' in ServiceTypes");
KConfig *config=new KConfig("default_components");
config->setGroup("KTextEditor");
- QString editor = config->readPathEntry("embeddedEditor");
+ TQString editor = config->readPathEntry("embeddedEditor");
if (editor.isEmpty()) editor="katepart";
@@ -74,11 +74,11 @@ EditorChooser:: ~EditorChooser(){
delete d;
}
-void EditorChooser::readAppSetting(const QString& postfix){
+void EditorChooser::readAppSetting(const TQString& postfix){
KConfig *cfg=kapp->config();
- QString previousGroup=cfg->group();
+ TQString previousGroup=cfg->group();
cfg->setGroup("KTEXTEDITOR:"+postfix);
- QString editor=cfg->readPathEntry("editor");
+ TQString editor=cfg->readPathEntry("editor");
if (editor.isEmpty()) d->chooser->editorCombo->setCurrentItem(0);
else
{
@@ -89,26 +89,26 @@ void EditorChooser::readAppSetting(const QString& postfix){
cfg->setGroup(previousGroup);
}
-void EditorChooser::writeAppSetting(const QString& postfix){
+void EditorChooser::writeAppSetting(const TQString& postfix){
KConfig *cfg=kapp->config();
- QString previousGroup=cfg->group();
+ TQString previousGroup=cfg->group();
cfg->setGroup("KTEXTEDITOR:"+postfix);
cfg->writeEntry("DEVELOPER_INFO","NEVER TRY TO USE VALUES FROM THAT GROUP, THEY ARE SUBJECT TO CHANGES");
cfg->writePathEntry("editor", (d->chooser->editorCombo->currentItem()==0) ?
- QString::null : (*d->elements.at(d->chooser->editorCombo->currentItem()-1)));
+ TQString::null : (*d->elements.at(d->chooser->editorCombo->currentItem()-1)));
cfg->sync();
cfg->setGroup(previousGroup);
}
-KTextEditor::Document *EditorChooser::createDocument(QObject *parent,const char* name, const QString& postfix,bool fallBackToKatePart){
+KTextEditor::Document *EditorChooser::createDocument(TQObject *parent,const char* name, const TQString& postfix,bool fallBackToKatePart){
KTextEditor::Document *tmpDoc=0;
KConfig *cfg=kapp->config();
- QString previousGroup=cfg->group();
+ TQString previousGroup=cfg->group();
cfg->setGroup("KTEXTEDITOR:"+postfix);
- QString editor=cfg->readPathEntry("editor");
+ TQString editor=cfg->readPathEntry("editor");
cfg->setGroup(previousGroup);
if (editor.isEmpty())
{
@@ -130,15 +130,15 @@ KTextEditor::Document *EditorChooser::createDocument(QObject *parent,const char*
return 0;
}
-KTextEditor::Editor *EditorChooser::createEditor(QWidget *parentWidget,QObject *parent,const char* widgetName,
- const char* name,const QString& postfix,bool fallBackToKatePart){
+KTextEditor::Editor *EditorChooser::createEditor(TQWidget *parentWidget,TQObject *parent,const char* widgetName,
+ const char* name,const TQString& postfix,bool fallBackToKatePart){
KTextEditor::Editor *tmpEd=0;
KConfig *cfg=kapp->config();
- QString previousGroup=cfg->group();
+ TQString previousGroup=cfg->group();
cfg->setGroup("KTEXTEDITOR:"+postfix);
- QString editor=cfg->readPathEntry("editor");
+ TQString editor=cfg->readPathEntry("editor");
cfg->setGroup(previousGroup);
if (editor.isEmpty())
{
diff --git a/interfaces/ktexteditor/editorchooser.h b/interfaces/ktexteditor/editorchooser.h
index 3feb73b62..156c49473 100644
--- a/interfaces/ktexteditor/editorchooser.h
+++ b/interfaces/ktexteditor/editorchooser.h
@@ -4,7 +4,7 @@
#include <ktexteditor/editor.h>
#include <ktexteditor/document.h>
-#include <qwidget.h>
+#include <tqwidget.h>
class KConfig;
class QString;
@@ -19,16 +19,16 @@ class KTEXTEDITOR_EXPORT EditorChooser: public QWidget
Q_OBJECT
public:
- EditorChooser(QWidget *parent=0,const char *name=0);
+ EditorChooser(TQWidget *parent=0,const char *name=0);
virtual ~EditorChooser();
/* void writeSysDefault();*/
- void readAppSetting(const QString& postfix=QString::null);
- void writeAppSetting(const QString& postfix=QString::null);
+ void readAppSetting(const TQString& postfix=TQString::null);
+ void writeAppSetting(const TQString& postfix=TQString::null);
- static KTextEditor::Document *createDocument(QObject* parent=0,const char *name=0,const QString& postfix=QString::null, bool fallBackToKatePart=true);
- static KTextEditor::Editor *createEditor(QWidget *parentWidget,QObject *parent,const char* widgetName=0,const char* name=0,const QString& postfix=QString::null,bool fallBackToKatePart=true);
+ static KTextEditor::Document *createDocument(TQObject* parent=0,const char *name=0,const TQString& postfix=TQString::null, bool fallBackToKatePart=true);
+ static KTextEditor::Editor *createEditor(TQWidget *parentWidget,TQObject *parent,const char* widgetName=0,const char* name=0,const TQString& postfix=TQString::null,bool fallBackToKatePart=true);
private:
class PrivateEditorChooser *d;
};
@@ -38,18 +38,18 @@ class EditorChooserBackEnd: public ComponentChooserPlugin {
Q_OBJECT
public:
- EditorChooserBackEnd(QObject *parent=0, const char *name=0);
+ EditorChooserBackEnd(TQObject *parent=0, const char *name=0);
virtual ~EditorChooserBackEnd();
- virtual QWidget *widget(QWidget *);
- virtual const QStringList &choices();
+ virtual TQWidget *widget(TQWidget *);
+ virtual const TQStringList &choices();
virtual void saveSettings();
- void readAppSetting(KConfig *cfg,const QString& postfix);
- void writeAppSetting(KConfig *cfg,const QString& postfix);
+ void readAppSetting(KConfig *cfg,const TQString& postfix);
+ void writeAppSetting(KConfig *cfg,const TQString& postfix);
public slots:
- virtual void madeChoice(int pos,const QString &choice);
+ virtual void madeChoice(int pos,const TQString &choice);
};
*/
diff --git a/interfaces/ktexteditor/encodingdcopinterface.cpp b/interfaces/ktexteditor/encodingdcopinterface.cpp
index adf369c6d..eb408c16e 100644
--- a/interfaces/ktexteditor/encodingdcopinterface.cpp
+++ b/interfaces/ktexteditor/encodingdcopinterface.cpp
@@ -18,11 +18,11 @@ uint EncodingDCOPInterface::encodingInterfaceNumber ()
{
return m_parent->encodingInterfaceNumber ();
}
-void EncodingDCOPInterface::setEncoding (QString e)
+void EncodingDCOPInterface::setEncoding (TQString e)
{
m_parent->setEncoding (e);
}
-QString EncodingDCOPInterface::encoding()
+TQString EncodingDCOPInterface::encoding()
{
return m_parent->encoding();
}
diff --git a/interfaces/ktexteditor/encodingdcopinterface.h b/interfaces/ktexteditor/encodingdcopinterface.h
index b5996deee..38de4e0aa 100644
--- a/interfaces/ktexteditor/encodingdcopinterface.h
+++ b/interfaces/ktexteditor/encodingdcopinterface.h
@@ -3,8 +3,8 @@
#include <dcopobject.h>
#include <dcopref.h>
-#include <qstringlist.h>
-#include <qcstring.h>
+#include <tqstringlist.h>
+#include <tqcstring.h>
//#include "editdcopinterface.moc"
namespace KTextEditor
{
@@ -34,8 +34,8 @@ namespace KTextEditor
virtual ~EncodingDCOPInterface();
k_dcop:
uint encodingInterfaceNumber ();
- void setEncoding (QString e) ;
- QString encoding();
+ void setEncoding (TQString e) ;
+ TQString encoding();
private:
EncodingInterface *m_parent;
diff --git a/interfaces/ktexteditor/encodinginterface.cpp b/interfaces/ktexteditor/encodinginterface.cpp
index b27204862..341847fb7 100644
--- a/interfaces/ktexteditor/encodinginterface.cpp
+++ b/interfaces/ktexteditor/encodinginterface.cpp
@@ -47,7 +47,7 @@ EncodingInterface::EncodingInterface()
myEncodingInterfaceNumber = globalEncodingInterfaceNumber++;
d = new PrivateEncodingInterface();
- ::QString name = "EncodingInterface#" + ::QString::number(myEncodingInterfaceNumber);
+ ::TQString name = "EncodingInterface#" + ::TQString::number(myEncodingInterfaceNumber);
d->interface = new EncodingDCOPInterface(this, name.latin1());
}
@@ -62,7 +62,7 @@ unsigned int EncodingInterface::encodingInterfaceNumber () const
return myEncodingInterfaceNumber;
}
-void EncodingInterface::setEncodingInterfaceDCOPSuffix (const QCString &suffix)
+void EncodingInterface::setEncodingInterfaceDCOPSuffix (const TQCString &suffix)
{
d->interface->setObjId ("EncodingInterface#"+suffix);
}
diff --git a/interfaces/ktexteditor/encodinginterface.h b/interfaces/ktexteditor/encodinginterface.h
index 245090e2e..6bd01be38 100644
--- a/interfaces/ktexteditor/encodinginterface.h
+++ b/interfaces/ktexteditor/encodinginterface.h
@@ -41,14 +41,14 @@ class KTEXTEDITOR_EXPORT EncodingInterface
unsigned int encodingInterfaceNumber () const;
protected:
- void setEncodingInterfaceDCOPSuffix (const QCString &suffix);
+ void setEncodingInterfaceDCOPSuffix (const TQCString &suffix);
//
// slots !!!
//
public:
- virtual void setEncoding (const class QString &e) = 0;
- virtual class QString encoding() const = 0;
+ virtual void setEncoding (const class TQString &e) = 0;
+ virtual class TQString encoding() const = 0;
private:
class PrivateEncodingInterface *d;
diff --git a/interfaces/ktexteditor/highlightinginterface.cpp b/interfaces/ktexteditor/highlightinginterface.cpp
index 8f0db5204..f606ab5c0 100644
--- a/interfaces/ktexteditor/highlightinginterface.cpp
+++ b/interfaces/ktexteditor/highlightinginterface.cpp
@@ -55,7 +55,7 @@ unsigned int HighlightingInterface::highlightingInterfaceNumber () const
return myHighlightingInterfaceNumber;
}
-void HighlightingInterface::setHighlightingInterfaceDCOPSuffix (const QCString &/*suffix*/)
+void HighlightingInterface::setHighlightingInterfaceDCOPSuffix (const TQCString &/*suffix*/)
{
//d->interface->setObjId ("HighlightingInterface#"+suffix);
}
diff --git a/interfaces/ktexteditor/highlightinginterface.h b/interfaces/ktexteditor/highlightinginterface.h
index 08784085c..707665b5e 100644
--- a/interfaces/ktexteditor/highlightinginterface.h
+++ b/interfaces/ktexteditor/highlightinginterface.h
@@ -42,7 +42,7 @@ class KTEXTEDITOR_EXPORT HighlightingInterface
unsigned int highlightingInterfaceNumber () const;
protected:
- void setHighlightingInterfaceDCOPSuffix (const QCString &suffix);
+ void setHighlightingInterfaceDCOPSuffix (const TQCString &suffix);
//
// slots !!!
@@ -66,12 +66,12 @@ class KTEXTEDITOR_EXPORT HighlightingInterface
/**
* returns the name of the highlighting with number "mode"
*/
- virtual QString hlModeName (unsigned int mode) = 0;
+ virtual TQString hlModeName (unsigned int mode) = 0;
/**
* returns the sectionname of the highlighting with number "mode"
*/
- virtual QString hlModeSectionName (unsigned int mode) = 0;
+ virtual TQString hlModeSectionName (unsigned int mode) = 0;
//
// signals !!!
diff --git a/interfaces/ktexteditor/ktexteditor.cpp b/interfaces/ktexteditor/ktexteditor.cpp
index be92cdedb..0b50fdaeb 100644
--- a/interfaces/ktexteditor/ktexteditor.cpp
+++ b/interfaces/ktexteditor/ktexteditor.cpp
@@ -106,7 +106,7 @@ unsigned int Plugin::globalPluginNumber = 0;
unsigned int PluginViewInterface::globalPluginViewInterfaceNumber = 0;
unsigned int Editor::globalEditorNumber = 0;
-Document::Document( QObject *parent, const char *name ) : KTextEditor::Editor (parent, name )
+Document::Document( TQObject *parent, const char *name ) : KTextEditor::Editor (parent, name )
{
globalDocumentNumber++;
myDocumentNumber = globalDocumentNumber;
@@ -121,15 +121,15 @@ unsigned int Document::documentNumber () const
return myDocumentNumber;
}
-QCString Document::documentDCOPSuffix () const
+TQCString Document::documentDCOPSuffix () const
{
- QCString num;
+ TQCString num;
num.setNum (documentNumber());
return num;
}
-View::View( Document *, QWidget *parent, const char *name ) : QWidget( parent, name )
+View::View( Document *, TQWidget *parent, const char *name ) : TQWidget( parent, name )
{
globalViewNumber++;
myViewNumber = globalViewNumber;
@@ -144,16 +144,16 @@ unsigned int View::viewNumber () const
return myViewNumber;
}
-QCString View::viewDCOPSuffix () const
+TQCString View::viewDCOPSuffix () const
{
- QCString num1, num2;
+ TQCString num1, num2;
num1.setNum (viewNumber());
num2.setNum (document()->documentNumber());
return num2 + "-" + num1;
}
-Plugin::Plugin( Document *document, const char *name ) : QObject (document, name )
+Plugin::Plugin( Document *document, const char *name ) : TQObject (document, name )
{
globalPluginNumber++;
myPluginNumber = globalPluginNumber;
@@ -191,7 +191,7 @@ unsigned int PluginViewInterface::pluginViewInterfaceNumber () const
return myPluginViewInterfaceNumber;
}
-Editor::Editor( QObject *parent, const char *name ) : KParts::ReadWritePart( parent, name )
+Editor::Editor( TQObject *parent, const char *name ) : KParts::ReadWritePart( parent, name )
{
globalEditorNumber++;
myEditorNumber = globalEditorNumber;
@@ -206,12 +206,12 @@ unsigned int Editor::editorNumber () const
return myEditorNumber;
}
-Editor *KTextEditor::createEditor ( const char* libname, QWidget *parentWidget, const char *widgetName, QObject *parent, const char *name )
+Editor *KTextEditor::createEditor ( const char* libname, TQWidget *parentWidget, const char *widgetName, TQObject *parent, const char *name )
{
return KParts::ComponentFactory::createPartInstanceFromLibrary<Editor>( libname, parentWidget, widgetName, parent, name );
}
-Document *KTextEditor::createDocument ( const char* libname, QObject *parent, const char *name )
+Document *KTextEditor::createDocument ( const char* libname, TQObject *parent, const char *name )
{
return KParts::ComponentFactory::createPartInstanceFromLibrary<Document>( libname, 0, 0, parent, name );
}
diff --git a/interfaces/ktexteditor/markinterface.cpp b/interfaces/ktexteditor/markinterface.cpp
index 4b1127d9e..d711b5245 100644
--- a/interfaces/ktexteditor/markinterface.cpp
+++ b/interfaces/ktexteditor/markinterface.cpp
@@ -55,7 +55,7 @@ unsigned int MarkInterface::markInterfaceNumber () const
return myMarkInterfaceNumber;
}
-void MarkInterface::setMarkInterfaceDCOPSuffix (const QCString &/*suffix*/)
+void MarkInterface::setMarkInterfaceDCOPSuffix (const TQCString &/*suffix*/)
{
//d->interface->setObjId ("MarkInterface#"+suffix);
}
diff --git a/interfaces/ktexteditor/markinterface.h b/interfaces/ktexteditor/markinterface.h
index 84e1a6758..7fbb03e00 100644
--- a/interfaces/ktexteditor/markinterface.h
+++ b/interfaces/ktexteditor/markinterface.h
@@ -20,7 +20,7 @@
#ifndef __ktexteditor_markinterface_h__
#define __ktexteditor_markinterface_h__
-#include <qptrlist.h>
+#include <tqptrlist.h>
#include <kdelibs_export.h>
@@ -50,7 +50,7 @@ class KTEXTEDITOR_EXPORT MarkInterface
unsigned int markInterfaceNumber () const;
protected:
- void setMarkInterfaceDCOPSuffix (const QCString &suffix);
+ void setMarkInterfaceDCOPSuffix (const TQCString &suffix);
//
// slots !!!
@@ -80,7 +80,7 @@ class KTEXTEDITOR_EXPORT MarkInterface
/**
* @return a list of all marks in the document
*/
- virtual QPtrList<KTextEditor::Mark> marks () = 0;
+ virtual TQPtrList<KTextEditor::Mark> marks () = 0;
/**
* Clears all marks in the document.
*/
diff --git a/interfaces/ktexteditor/markinterfaceextension.cpp b/interfaces/ktexteditor/markinterfaceextension.cpp
index 73f429fe8..57c981421 100644
--- a/interfaces/ktexteditor/markinterfaceextension.cpp
+++ b/interfaces/ktexteditor/markinterfaceextension.cpp
@@ -55,7 +55,7 @@ unsigned int MarkInterfaceExtension::markInterfaceExtensionNumber () const
return myMarkInterfaceExtensionNumber;
}
-void MarkInterfaceExtension::setMarkInterfaceExtensionDCOPSuffix (const QCString &/*suffix*/)
+void MarkInterfaceExtension::setMarkInterfaceExtensionDCOPSuffix (const TQCString &/*suffix*/)
{
//d->interface->setObjId ("MarkInterfaceExtension#"+suffix);
}
diff --git a/interfaces/ktexteditor/markinterfaceextension.h b/interfaces/ktexteditor/markinterfaceextension.h
index cebe150f3..984664315 100644
--- a/interfaces/ktexteditor/markinterfaceextension.h
+++ b/interfaces/ktexteditor/markinterfaceextension.h
@@ -20,9 +20,9 @@
#ifndef __ktexteditor_markinterface_extension_h__
#define __ktexteditor_markinterface_extension_h__
-#include <qptrlist.h>
-#include <qpixmap.h>
-#include <qstring.h>
+#include <tqptrlist.h>
+#include <tqpixmap.h>
+#include <tqstring.h>
#include "markinterface.h"
class QCString;
@@ -47,11 +47,11 @@ class KTEXTEDITOR_EXPORT MarkInterfaceExtension
unsigned int markInterfaceExtensionNumber () const;
protected:
- void setMarkInterfaceExtensionDCOPSuffix (const QCString &suffix);
+ void setMarkInterfaceExtensionDCOPSuffix (const TQCString &suffix);
public:
- virtual void setPixmap(MarkInterface::MarkTypes, const QPixmap &)=0;
- virtual void setDescription(MarkInterface::MarkTypes, const QString &)=0;
+ virtual void setPixmap(MarkInterface::MarkTypes, const TQPixmap &)=0;
+ virtual void setDescription(MarkInterface::MarkTypes, const TQString &)=0;
virtual void setMarksUserChangable(uint markMask)=0;
enum MarkChangeAction {
diff --git a/interfaces/ktexteditor/plugin.h b/interfaces/ktexteditor/plugin.h
index f96e50ddd..dc7978f92 100644
--- a/interfaces/ktexteditor/plugin.h
+++ b/interfaces/ktexteditor/plugin.h
@@ -19,7 +19,7 @@
#ifndef __ktexteditor_plugin_h__
#define __ktexteditor_plugin_h__
-#include <qobject.h>
+#include <tqobject.h>
#include <kdelibs_export.h>
diff --git a/interfaces/ktexteditor/popupmenuinterface.cpp b/interfaces/ktexteditor/popupmenuinterface.cpp
index 30fe4303f..d2d51e4af 100644
--- a/interfaces/ktexteditor/popupmenuinterface.cpp
+++ b/interfaces/ktexteditor/popupmenuinterface.cpp
@@ -55,7 +55,7 @@ unsigned int PopupMenuInterface::popupMenuInterfaceNumber () const
return myPopupMenuInterfaceNumber;
}
-void PopupMenuInterface::setPopupMenuInterfaceDCOPSuffix (const QCString &/*suffix*/)
+void PopupMenuInterface::setPopupMenuInterfaceDCOPSuffix (const TQCString &/*suffix*/)
{
//d->interface->setObjId ("PopupMenuInterface#"+suffix);
}
diff --git a/interfaces/ktexteditor/popupmenuinterface.h b/interfaces/ktexteditor/popupmenuinterface.h
index f1d07b806..4288cd605 100644
--- a/interfaces/ktexteditor/popupmenuinterface.h
+++ b/interfaces/ktexteditor/popupmenuinterface.h
@@ -41,7 +41,7 @@ class KTEXTEDITOR_EXPORT PopupMenuInterface
unsigned int popupMenuInterfaceNumber () const;
protected:
- void setPopupMenuInterfaceDCOPSuffix (const QCString &suffix);
+ void setPopupMenuInterfaceDCOPSuffix (const TQCString &suffix);
//
// normal methodes
@@ -51,7 +51,7 @@ class KTEXTEDITOR_EXPORT PopupMenuInterface
Install a Popup Menu. The Popup Menu will be activated on
a right mouse button press event.
*/
- virtual void installPopup (QPopupMenu *rmb_Menu) = 0;
+ virtual void installPopup (TQPopupMenu *rmb_Menu) = 0;
private:
class PrivatePopupMenuInterface *d;
diff --git a/interfaces/ktexteditor/printdcopinterface.h b/interfaces/ktexteditor/printdcopinterface.h
index 420def4cc..e41e6da5d 100644
--- a/interfaces/ktexteditor/printdcopinterface.h
+++ b/interfaces/ktexteditor/printdcopinterface.h
@@ -3,8 +3,8 @@
#include <dcopobject.h>
#include <dcopref.h>
-#include <qstringlist.h>
-#include <qcstring.h>
+#include <tqstringlist.h>
+#include <tqcstring.h>
//#include "editdcopinterface.moc"
namespace KTextEditor
{
diff --git a/interfaces/ktexteditor/printinterface.cpp b/interfaces/ktexteditor/printinterface.cpp
index 655e610bb..936e803ea 100644
--- a/interfaces/ktexteditor/printinterface.cpp
+++ b/interfaces/ktexteditor/printinterface.cpp
@@ -45,7 +45,7 @@ PrintInterface::PrintInterface()
myPrintInterfaceNumber = globalPrintInterfaceNumber++;
d = new PrivatePrintInterface();
- QString name = "PrintInterface#" + QString::number(myPrintInterfaceNumber);
+ TQString name = "PrintInterface#" + TQString::number(myPrintInterfaceNumber);
d->interface = new PrintDCOPInterface(this, name.latin1());
}
@@ -60,7 +60,7 @@ unsigned int PrintInterface::printInterfaceNumber () const
return myPrintInterfaceNumber;
}
-void PrintInterface::setPrintInterfaceDCOPSuffix (const QCString &suffix)
+void PrintInterface::setPrintInterfaceDCOPSuffix (const TQCString &suffix)
{
d->interface->setObjId ("PrintInterface#"+suffix);
}
diff --git a/interfaces/ktexteditor/printinterface.h b/interfaces/ktexteditor/printinterface.h
index a2af1d0c4..758a64f7a 100644
--- a/interfaces/ktexteditor/printinterface.h
+++ b/interfaces/ktexteditor/printinterface.h
@@ -41,7 +41,7 @@ class KTEXTEDITOR_EXPORT PrintInterface
unsigned int printInterfaceNumber () const;
protected:
- void setPrintInterfaceDCOPSuffix (const QCString &suffix);
+ void setPrintInterfaceDCOPSuffix (const TQCString &suffix);
//
// slots !!!
diff --git a/interfaces/ktexteditor/searchdcopinterface.cpp b/interfaces/ktexteditor/searchdcopinterface.cpp
index ce4fe516d..ce29e4927 100644
--- a/interfaces/ktexteditor/searchdcopinterface.cpp
+++ b/interfaces/ktexteditor/searchdcopinterface.cpp
@@ -2,7 +2,7 @@
#include "searchinterface.h"
#include <dcopclient.h>
-#include <qregexp.h>
+#include <tqregexp.h>
using namespace KTextEditor;
@@ -20,16 +20,16 @@ SearchDCOPInterface::~SearchDCOPInterface()
}
-bool SearchDCOPInterface::findFirstString( QString text, bool caseSensitive)
+bool SearchDCOPInterface::findFirstString( TQString text, bool caseSensitive)
{
return m_parent->searchText(0, 0, text, &m_currentrow, &m_currentcol, &m_currentmatchlen, caseSensitive);
}
-bool SearchDCOPInterface::findNextString( QString text, bool caseSensitive)
+bool SearchDCOPInterface::findNextString( TQString text, bool caseSensitive)
{
return m_parent->searchText(m_currentrow, m_currentcol+1, text, &m_currentrow, &m_currentcol, &m_currentmatchlen, caseSensitive);
}
-bool SearchDCOPInterface::findPreviousString( QString text, bool caseSensitive)
+bool SearchDCOPInterface::findPreviousString( TQString text, bool caseSensitive)
{
if( m_currentcol == 0)
m_currentrow--;
@@ -38,45 +38,45 @@ bool SearchDCOPInterface::findPreviousString( QString text, bool caseSensitive)
return m_parent->searchText(m_currentrow, m_currentcol, text, &m_currentrow, &m_currentcol, &m_currentmatchlen, caseSensitive, true);
}
-bool SearchDCOPInterface::findLastString( QString text, bool caseSensitive)
+bool SearchDCOPInterface::findLastString( TQString text, bool caseSensitive)
{
return m_parent->searchText(0,0, text, &m_currentrow, &m_currentcol, &m_currentmatchlen, caseSensitive, true);
}
-bool SearchDCOPInterface::findStringAt( uint row, uint col, QString text, bool caseSensitive)
+bool SearchDCOPInterface::findStringAt( uint row, uint col, TQString text, bool caseSensitive)
{
return m_parent->searchText(row,col, text, &m_currentrow, &m_currentcol, &m_currentmatchlen, caseSensitive);
}
-bool SearchDCOPInterface::findFirstRegExp( QString regexp)
+bool SearchDCOPInterface::findFirstRegExp( TQString regexp)
{
- return m_parent->searchText( 0,0, QRegExp(regexp), &m_currentrow, &m_currentcol, &m_currentmatchlen);
+ return m_parent->searchText( 0,0, TQRegExp(regexp), &m_currentrow, &m_currentcol, &m_currentmatchlen);
}
-bool SearchDCOPInterface::findNextRegExp( QString regexp)
+bool SearchDCOPInterface::findNextRegExp( TQString regexp)
{
- return m_parent->searchText( m_currentrow, m_currentcol+1, QRegExp(regexp), &m_currentrow, &m_currentcol, &m_currentmatchlen);
+ return m_parent->searchText( m_currentrow, m_currentcol+1, TQRegExp(regexp), &m_currentrow, &m_currentcol, &m_currentmatchlen);
}
-bool SearchDCOPInterface::findPreviousRegExp( QString regexp)
+bool SearchDCOPInterface::findPreviousRegExp( TQString regexp)
{
if( m_currentcol == 0)
m_currentrow--;
else
m_currentcol--;
- return m_parent->searchText( m_currentrow, m_currentcol, QRegExp(regexp), &m_currentrow, &m_currentcol, &m_currentmatchlen, true);
+ return m_parent->searchText( m_currentrow, m_currentcol, TQRegExp(regexp), &m_currentrow, &m_currentcol, &m_currentmatchlen, true);
}
-bool SearchDCOPInterface::findLastRegExp(QString regexp)
+bool SearchDCOPInterface::findLastRegExp(TQString regexp)
{
- return m_parent->searchText( 0,0, QRegExp(regexp), &m_currentrow, &m_currentcol, &m_currentmatchlen, true);
+ return m_parent->searchText( 0,0, TQRegExp(regexp), &m_currentrow, &m_currentcol, &m_currentmatchlen, true);
}
-bool SearchDCOPInterface::findRegExpAt( uint row, uint col, QString regexp)
+bool SearchDCOPInterface::findRegExpAt( uint row, uint col, TQString regexp)
{
- return m_parent->searchText( row, col, QRegExp(regexp), &m_currentrow, &m_currentcol, &m_currentmatchlen, false);
+ return m_parent->searchText( row, col, TQRegExp(regexp), &m_currentrow, &m_currentcol, &m_currentmatchlen, false);
}
uint SearchDCOPInterface::currentMatchLine()
diff --git a/interfaces/ktexteditor/searchdcopinterface.h b/interfaces/ktexteditor/searchdcopinterface.h
index a16af1bd6..d4f558a26 100644
--- a/interfaces/ktexteditor/searchdcopinterface.h
+++ b/interfaces/ktexteditor/searchdcopinterface.h
@@ -3,8 +3,8 @@
#include <dcopobject.h>
#include <dcopref.h>
-#include <qstringlist.h>
-#include <qcstring.h>
+#include <tqstringlist.h>
+#include <tqcstring.h>
namespace KTextEditor
{
@@ -33,17 +33,17 @@ namespace KTextEditor
**/
virtual ~SearchDCOPInterface();
k_dcop:
- bool findFirstString(QString text, bool caseSensitive);
- bool findNextString(QString text, bool caseSensitive);
- bool findPreviousString( QString text, bool caseSensitive);
- bool findLastString(QString text, bool caseSensitive);
- bool findStringAt( uint row, uint col, QString text, bool caseSensitive);
+ bool findFirstString(TQString text, bool caseSensitive);
+ bool findNextString(TQString text, bool caseSensitive);
+ bool findPreviousString( TQString text, bool caseSensitive);
+ bool findLastString(TQString text, bool caseSensitive);
+ bool findStringAt( uint row, uint col, TQString text, bool caseSensitive);
- bool findFirstRegExp( QString regexp);
- bool findNextRegExp( QString regexp);
- bool findPreviousRegExp( QString regexp);
- bool findLastRegExp( QString regexp);
- bool findRegExpAt( uint row, uint col, QString regexp);
+ bool findFirstRegExp( TQString regexp);
+ bool findNextRegExp( TQString regexp);
+ bool findPreviousRegExp( TQString regexp);
+ bool findLastRegExp( TQString regexp);
+ bool findRegExpAt( uint row, uint col, TQString regexp);
uint currentMatchLine();
uint currentMatchCol();
diff --git a/interfaces/ktexteditor/searchinterface.cpp b/interfaces/ktexteditor/searchinterface.cpp
index 738567e87..d23a25e31 100644
--- a/interfaces/ktexteditor/searchinterface.cpp
+++ b/interfaces/ktexteditor/searchinterface.cpp
@@ -27,7 +27,7 @@ SearchInterface::SearchInterface()
d = new PrivateSearchInterface();
globalSearchInterfaceNumber++;
mySearchInterfaceNumber=globalSearchInterfaceNumber;
- QString name = "SearchInterface#" + QString::number(mySearchInterfaceNumber);
+ TQString name = "SearchInterface#" + TQString::number(mySearchInterfaceNumber);
d->interface = new SearchDCOPInterface(this, name.latin1());
}
SearchInterface::~SearchInterface()
@@ -41,7 +41,7 @@ unsigned int SearchInterface::searchInterfaceNumber () const
return mySearchInterfaceNumber;
}
-void SearchInterface::setSearchInterfaceDCOPSuffix (const QCString &suffix)
+void SearchInterface::setSearchInterfaceDCOPSuffix (const TQCString &suffix)
{
d->interface->setObjId ("SearchInterface#"+suffix);
}
diff --git a/interfaces/ktexteditor/searchinterface.h b/interfaces/ktexteditor/searchinterface.h
index 1fd6823d3..b1c5f5f9f 100644
--- a/interfaces/ktexteditor/searchinterface.h
+++ b/interfaces/ktexteditor/searchinterface.h
@@ -43,14 +43,14 @@ class KTEXTEDITOR_EXPORT SearchInterface
unsigned int searchInterfaceNumber () const;
protected:
- void setSearchInterfaceDCOPSuffix (const QCString &suffix);
+ void setSearchInterfaceDCOPSuffix (const TQCString &suffix);
//
// slots !!!
//
public:
- virtual bool searchText (unsigned int startLine, unsigned int startCol, const QString &text, unsigned int *foundAtLine, unsigned int *foundAtCol, unsigned int *matchLen, bool casesensitive = true, bool backwards = false) = 0;
- virtual bool searchText (unsigned int startLine, unsigned int startCol, const QRegExp &regexp, unsigned int *foundAtLine, unsigned int *foundAtCol, unsigned int *matchLen, bool backwards = false) = 0;
+ virtual bool searchText (unsigned int startLine, unsigned int startCol, const TQString &text, unsigned int *foundAtLine, unsigned int *foundAtCol, unsigned int *matchLen, bool casesensitive = true, bool backwards = false) = 0;
+ virtual bool searchText (unsigned int startLine, unsigned int startCol, const TQRegExp &regexp, unsigned int *foundAtLine, unsigned int *foundAtCol, unsigned int *matchLen, bool backwards = false) = 0;
private:
class PrivateSearchInterface *d;
diff --git a/interfaces/ktexteditor/selectionextdcopinterface.h b/interfaces/ktexteditor/selectionextdcopinterface.h
index 65e7529ab..5c3e32baf 100644
--- a/interfaces/ktexteditor/selectionextdcopinterface.h
+++ b/interfaces/ktexteditor/selectionextdcopinterface.h
@@ -24,7 +24,7 @@
#include "selectioninterfaceext.h"
-#include <qstring.h>
+#include <tqstring.h>
#include <dcopobject.h>
#include <dcopref.h>
diff --git a/interfaces/ktexteditor/selectioninterface.cpp b/interfaces/ktexteditor/selectioninterface.cpp
index d568881d4..2e9ae5204 100644
--- a/interfaces/ktexteditor/selectioninterface.cpp
+++ b/interfaces/ktexteditor/selectioninterface.cpp
@@ -28,7 +28,7 @@ SelectionInterface::SelectionInterface()
d = new PrivateSelectionInterface();
globalSelectionInterfaceNumber++;
mySelectionInterfaceNumber = globalSelectionInterfaceNumber;
- QString name = "SelectionInterface#" + QString::number(mySelectionInterfaceNumber);
+ TQString name = "SelectionInterface#" + TQString::number(mySelectionInterfaceNumber);
d->interface = new SelectionDCOPInterface(this, name.latin1());
}
SelectionInterface::~SelectionInterface()
@@ -42,7 +42,7 @@ unsigned int SelectionInterface::selectionInterfaceNumber () const
return mySelectionInterfaceNumber;
}
-void SelectionInterface::setSelectionInterfaceDCOPSuffix (const QCString &suffix)
+void SelectionInterface::setSelectionInterfaceDCOPSuffix (const TQCString &suffix)
{
d->interface->setObjId ("SelectionInterface#"+suffix);
}
diff --git a/interfaces/ktexteditor/selectioninterfaceext.cpp b/interfaces/ktexteditor/selectioninterfaceext.cpp
index 471cfad65..f59468c17 100644
--- a/interfaces/ktexteditor/selectioninterfaceext.cpp
+++ b/interfaces/ktexteditor/selectioninterfaceext.cpp
@@ -43,7 +43,7 @@ SelectionInterfaceExt::SelectionInterfaceExt()
{
globalSelectionInterfaceExtNumber++;
mySelectionInterfaceExtNumber = globalSelectionInterfaceExtNumber;
- QString name = "SelectionInterfaceExt#" + QString::number(mySelectionInterfaceExtNumber);
+ TQString name = "SelectionInterfaceExt#" + TQString::number(mySelectionInterfaceExtNumber);
d->interface = new SelectionExtDCOPInterface(this, name.latin1());
}
@@ -58,7 +58,7 @@ unsigned int SelectionInterfaceExt::selectionInterfaceExtNumber () const
return mySelectionInterfaceExtNumber;
}
-void SelectionInterfaceExt::setSelectionInterfaceExtDCOPSuffix (const QCString &suffix)
+void SelectionInterfaceExt::setSelectionInterfaceExtDCOPSuffix (const TQCString &suffix)
{
d->interface->setObjId ("SelectionInterfaceExt#"+suffix);
}
diff --git a/interfaces/ktexteditor/selectioninterfaceext.h b/interfaces/ktexteditor/selectioninterfaceext.h
index 6b033ff34..407717ffd 100644
--- a/interfaces/ktexteditor/selectioninterfaceext.h
+++ b/interfaces/ktexteditor/selectioninterfaceext.h
@@ -46,7 +46,7 @@ class KTEXTEDITOR_EXPORT SelectionInterfaceExt
unsigned int selectionInterfaceExtNumber () const;
protected:
- void setSelectionInterfaceExtDCOPSuffix (const QCString &suffix);
+ void setSelectionInterfaceExtDCOPSuffix (const TQCString &suffix);
public:
/** The selection start line number */
diff --git a/interfaces/ktexteditor/sessionconfiginterface.cpp b/interfaces/ktexteditor/sessionconfiginterface.cpp
index be159bb4d..7180aae38 100644
--- a/interfaces/ktexteditor/sessionconfiginterface.cpp
+++ b/interfaces/ktexteditor/sessionconfiginterface.cpp
@@ -58,7 +58,7 @@ unsigned int SessionConfigInterface::configInterfaceNumber () const
return mySessionConfigInterfaceNumber;
}
-void SessionConfigInterface::setSessionConfigInterfaceDCOPSuffix (const QCString &/*suffix*/)
+void SessionConfigInterface::setSessionConfigInterfaceDCOPSuffix (const TQCString &/*suffix*/)
{
//d->interface->setObjId ("SessionConfigInterface#"+suffix);
}
diff --git a/interfaces/ktexteditor/sessionconfiginterface.h b/interfaces/ktexteditor/sessionconfiginterface.h
index fe392559b..5322d9f93 100644
--- a/interfaces/ktexteditor/sessionconfiginterface.h
+++ b/interfaces/ktexteditor/sessionconfiginterface.h
@@ -42,7 +42,7 @@ class KTEXTEDITOR_EXPORT SessionConfigInterface
unsigned int configInterfaceNumber () const;
protected:
- void setSessionConfigInterfaceDCOPSuffix (const QCString &suffix);
+ void setSessionConfigInterfaceDCOPSuffix (const TQCString &suffix);
//
// slots !!!
diff --git a/interfaces/ktexteditor/templateinterface.cpp b/interfaces/ktexteditor/templateinterface.cpp
index 3a96a8d5a..4f9f83706 100644
--- a/interfaces/ktexteditor/templateinterface.cpp
+++ b/interfaces/ktexteditor/templateinterface.cpp
@@ -21,11 +21,11 @@
#include <stdaddressbook.h>
#include <addressee.h>
#include <addresseedialog.h>
-#include <qstring.h>
+#include <tqstring.h>
#include <klocale.h>
#include <kglobal.h>
-#include <qdatetime.h>
-#include <qregexp.h>
+#include <tqdatetime.h>
+#include <tqregexp.h>
#include <kmessagebox.h>
#include <kcalendarsystem.h>
#include <unistd.h>
@@ -49,7 +49,7 @@ uint TemplateInterface::templateInterfaceNumber () const
return myTemplateInterfaceNumber;
}
-void TemplateInterface::setTemplateInterfaceDCOPSuffix ( const QCString &suffix )
+void TemplateInterface::setTemplateInterfaceDCOPSuffix ( const TQCString &suffix )
{}
#define INITKABC do { \
@@ -70,18 +70,18 @@ void TemplateInterface::setTemplateInterfaceDCOPSuffix ( const QCString &suffix
} \
} while(false)
-bool TemplateInterface::expandMacros( QMap<QString, QString> &map, QWidget *parentWindow )
+bool TemplateInterface::expandMacros( TQMap<TQString, TQString> &map, TQWidget *parentWindow )
{
KABC::StdAddressBook *addrBook = 0;
KABC::Addressee userAddress;
- QDateTime datetime = QDateTime::currentDateTime();
- QDate date = datetime.date();
- QTime time = datetime.time();
+ TQDateTime datetime = TQDateTime::currentDateTime();
+ TQDate date = datetime.date();
+ TQTime time = datetime.time();
- QMap<QString,QString>::Iterator it;
+ TQMap<TQString,TQString>::Iterator it;
for ( it = map.begin(); it != map.end(); ++it )
{
- QString placeholder = it.key();
+ TQString placeholder = it.key();
if ( map[ placeholder ].isEmpty() )
{
if ( placeholder == "index" ) map[ placeholder ] = "i";
@@ -125,11 +125,11 @@ bool TemplateInterface::expandMacros( QMap<QString, QString> &map, QWidget *pare
}
else if ( placeholder == "month" )
{
- map[ placeholder ] = QString::number( KGlobal::locale() ->calendar() ->month( date ) );
+ map[ placeholder ] = TQString::number( KGlobal::locale() ->calendar() ->month( date ) );
}
else if ( placeholder == "day" )
{
- map[ placeholder ] = QString::number( KGlobal::locale() ->calendar() ->day( date ) );
+ map[ placeholder ] = TQString::number( KGlobal::locale() ->calendar() ->day( date ) );
}
else if ( placeholder == "hostname" )
{
@@ -137,7 +137,7 @@ bool TemplateInterface::expandMacros( QMap<QString, QString> &map, QWidget *pare
hostname[ 0 ] = 0;
gethostname( hostname, 255 );
hostname[ 255 ] = 0;
- map[ placeholder ] = QString::fromLocal8Bit( hostname );
+ map[ placeholder ] = TQString::fromLocal8Bit( hostname );
}
else if ( placeholder == "cursor" )
{
@@ -149,11 +149,11 @@ bool TemplateInterface::expandMacros( QMap<QString, QString> &map, QWidget *pare
return true;
}
-bool TemplateInterface::insertTemplateText ( uint line, uint column, const QString &templateString, const QMap<QString, QString> &initialValues, QWidget *parentWindow )
+bool TemplateInterface::insertTemplateText ( uint line, uint column, const TQString &templateString, const TQMap<TQString, TQString> &initialValues, TQWidget *parentWindow )
{
- QMap<QString, QString> enhancedInitValues( initialValues );
+ TQMap<TQString, TQString> enhancedInitValues( initialValues );
- QRegExp rx( "[$%]\\{([^}\\s]+)\\}" );
+ TQRegExp rx( "[$%]\\{([^}\\s]+)\\}" );
rx.setMinimal( true );
int pos = 0;
int opos = 0;
@@ -172,7 +172,7 @@ bool TemplateInterface::insertTemplateText ( uint line, uint column, const QStri
continue;
}
}
- QString placeholder = rx.cap( 1 );
+ TQString placeholder = rx.cap( 1 );
if ( ! enhancedInitValues.contains( placeholder ) )
enhancedInitValues[ placeholder ] = "";
diff --git a/interfaces/ktexteditor/templateinterface.h b/interfaces/ktexteditor/templateinterface.h
index c4cbca6b7..ec864a5e4 100644
--- a/interfaces/ktexteditor/templateinterface.h
+++ b/interfaces/ktexteditor/templateinterface.h
@@ -19,9 +19,9 @@
#ifndef __ktexteditor_templateinterface_h__
#define __ktexteditor_templateinterface_h__
-#include <qstring.h>
-#include <qmap.h>
-#include <qwidget.h>
+#include <tqstring.h>
+#include <tqmap.h>
+#include <tqwidget.h>
#include <kdelibs_export.h>
@@ -52,12 +52,12 @@ class KTEXTEDITOR_EXPORT TemplateInterface //should be named AbstractTemplateInt
* @return true if all macros was sucessfully expanded
* @see insertTemplateText for a list of supported macros
*/
- static bool expandMacros( QMap<QString, QString> &initialValues, QWidget *parentWindow );
+ static bool expandMacros( TQMap<TQString, TQString> &initialValues, TQWidget *parentWindow );
uint templateInterfaceNumber () const;
protected:
- void setTemplateInterfaceDCOPSuffix (const QCString &suffix);
+ void setTemplateInterfaceDCOPSuffix (const TQCString &suffix);
public:
@@ -103,7 +103,7 @@ class KTEXTEDITOR_EXPORT TemplateInterface //should be named AbstractTemplateInt
* If the editor supports some kind of smart indentation, the inserted code
* should be layouted by the indenter.
*/
- bool insertTemplateText ( uint line, uint column, const QString &templateString, const QMap<QString,QString> &initialValues, QWidget *parentWindow=0);
+ bool insertTemplateText ( uint line, uint column, const TQString &templateString, const TQMap<TQString,TQString> &initialValues, TQWidget *parentWindow=0);
protected:
/**
@@ -113,7 +113,7 @@ protected:
* insertTemplateText above.
* @return true if any text was inserted.
*/
- virtual bool insertTemplateTextImplementation ( uint line, uint column, const QString &templateString, const QMap<QString,QString> &initialValues, QWidget *parentWindow=0 )=0;
+ virtual bool insertTemplateTextImplementation ( uint line, uint column, const TQString &templateString, const TQMap<TQString,TQString> &initialValues, TQWidget *parentWindow=0 )=0;
/**
* only for the interface itself - REAL PRIVATE
diff --git a/interfaces/ktexteditor/texthintinterface.h b/interfaces/ktexteditor/texthintinterface.h
index 3b5f0476d..aba23e944 100644
--- a/interfaces/ktexteditor/texthintinterface.h
+++ b/interfaces/ktexteditor/texthintinterface.h
@@ -19,8 +19,8 @@
#ifndef __ktexteditor_texthintinterface_h__
#define __ktexteditor_texthintinterface_h__
-#include <qstring.h>
-#include <qstringlist.h>
+#include <tqstring.h>
+#include <tqstringlist.h>
#include <kdelibs_export.h>
@@ -64,7 +64,7 @@ public:
* I you don't want a tooltip to be displayd set text to an emtpy string in a connected slot,
* otherwise set text to the string you want the editor to display
*/
- virtual void needTextHint(int line, int col, QString &text)=0;
+ virtual void needTextHint(int line, int col, TQString &text)=0;
private:
class PrivateTextHintInterface *d;
diff --git a/interfaces/ktexteditor/undodcopinterface.h b/interfaces/ktexteditor/undodcopinterface.h
index ff184fea4..b1a217036 100644
--- a/interfaces/ktexteditor/undodcopinterface.h
+++ b/interfaces/ktexteditor/undodcopinterface.h
@@ -3,8 +3,8 @@
#include <dcopobject.h>
#include <dcopref.h>
-#include <qstringlist.h>
-#include <qcstring.h>
+#include <tqstringlist.h>
+#include <tqcstring.h>
//#include "editdcopinterface.moc"
namespace KTextEditor
{
diff --git a/interfaces/ktexteditor/undointerface.cpp b/interfaces/ktexteditor/undointerface.cpp
index b0319f9c2..d19a56deb 100644
--- a/interfaces/ktexteditor/undointerface.cpp
+++ b/interfaces/ktexteditor/undointerface.cpp
@@ -45,7 +45,7 @@ UndoInterface::UndoInterface()
myUndoInterfaceNumber = globalUndoInterfaceNumber++;
d = new PrivateUndoInterface();
- QString name = "UndoInterface#" + QString::number(myUndoInterfaceNumber);
+ TQString name = "UndoInterface#" + TQString::number(myUndoInterfaceNumber);
d->interface = new UndoDCOPInterface(this, name.latin1());
}
@@ -60,7 +60,7 @@ unsigned int UndoInterface::undoInterfaceNumber () const
return myUndoInterfaceNumber;
}
-void UndoInterface::setUndoInterfaceDCOPSuffix (const QCString &suffix)
+void UndoInterface::setUndoInterfaceDCOPSuffix (const TQCString &suffix)
{
d->interface->setObjId ("UndoInterface#"+suffix);
}
diff --git a/interfaces/ktexteditor/undointerface.h b/interfaces/ktexteditor/undointerface.h
index 73146107e..e0fc77107 100644
--- a/interfaces/ktexteditor/undointerface.h
+++ b/interfaces/ktexteditor/undointerface.h
@@ -40,7 +40,7 @@ class KTEXTEDITOR_EXPORT UndoInterface
unsigned int undoInterfaceNumber () const;
protected:
- void setUndoInterfaceDCOPSuffix (const QCString &suffix);
+ void setUndoInterfaceDCOPSuffix (const TQCString &suffix);
//
// slots !!!
diff --git a/interfaces/ktexteditor/variableinterface.h b/interfaces/ktexteditor/variableinterface.h
index 84ed6013e..3df389b09 100644
--- a/interfaces/ktexteditor/variableinterface.h
+++ b/interfaces/ktexteditor/variableinterface.h
@@ -50,7 +50,7 @@ class KTEXTEDITOR_EXPORT VariableInterface
* @return the value of the variable @p name, or an empty string if the
* variable is not set or has no value.
*/
- virtual QString variable( const QString &name ) const = 0;
+ virtual TQString variable( const TQString &name ) const = 0;
//
// signals!!
@@ -59,7 +59,7 @@ class KTEXTEDITOR_EXPORT VariableInterface
/**
* Signal: emitted when a variable is set
*/
- virtual void variableChanged( const QString &variable, const QString &value ) = 0;
+ virtual void variableChanged( const TQString &variable, const TQString &value ) = 0;
private:
static unsigned int globalVariableInterfaceNumber;
diff --git a/interfaces/ktexteditor/view.h b/interfaces/ktexteditor/view.h
index e05dac5c7..caa14d021 100644
--- a/interfaces/ktexteditor/view.h
+++ b/interfaces/ktexteditor/view.h
@@ -19,7 +19,7 @@
#ifndef __ktexteditor_view_h__
#define __ktexteditor_view_h__
-#include <qwidget.h>
+#include <tqwidget.h>
#include <kxmlguiclient.h>
namespace KTextEditor
@@ -29,7 +29,7 @@ namespace KTextEditor
* The View class represents a single view of a Document .
*/
-class KTEXTEDITOR_EXPORT View : public QWidget, public KXMLGUIClient
+class KTEXTEDITOR_EXPORT View : public TQWidget, public KXMLGUIClient
{
friend class PrivateView;
@@ -39,7 +39,7 @@ class KTEXTEDITOR_EXPORT View : public QWidget, public KXMLGUIClient
/**
* Create a new view to the given document. The document must be non-null.
*/
- View ( class Document *, QWidget *parent, const char *name = 0 );
+ View ( class Document *, TQWidget *parent, const char *name = 0 );
virtual ~View ();
/**
@@ -50,7 +50,7 @@ class KTEXTEDITOR_EXPORT View : public QWidget, public KXMLGUIClient
/**
* Returns the DCOP suffix to allow identification of this view's DCOP interface.
*/
- QCString viewDCOPSuffix () const;
+ TQCString viewDCOPSuffix () const;
/**
* Acess the parent Document.
diff --git a/interfaces/ktexteditor/viewcursordcopinterface.cpp b/interfaces/ktexteditor/viewcursordcopinterface.cpp
index e6235ac9a..f26385414 100644
--- a/interfaces/ktexteditor/viewcursordcopinterface.cpp
+++ b/interfaces/ktexteditor/viewcursordcopinterface.cpp
@@ -1,7 +1,7 @@
#include "viewcursordcopinterface.h"
#include "viewcursorinterface.h"
-#include <qpoint.h>
+#include <tqpoint.h>
#include <dcopclient.h>
using namespace KTextEditor;
@@ -22,7 +22,7 @@ uint ViewCursorDCOPInterface::viewCursorInterfaceNumber ()
return m_parent->viewCursorInterfaceNumber ();
}
-::QPoint ViewCursorDCOPInterface::cursorCoordinates ()
+::TQPoint ViewCursorDCOPInterface::cursorCoordinates ()
{
return m_parent->cursorCoordinates ();
}
diff --git a/interfaces/ktexteditor/viewcursordcopinterface.h b/interfaces/ktexteditor/viewcursordcopinterface.h
index 9dd974a7d..4bae0b520 100644
--- a/interfaces/ktexteditor/viewcursordcopinterface.h
+++ b/interfaces/ktexteditor/viewcursordcopinterface.h
@@ -3,8 +3,8 @@
#include <dcopobject.h>
#include <dcopref.h>
-#include <qstringlist.h>
-#include <qcstring.h>
+#include <tqstringlist.h>
+#include <tqcstring.h>
//#include "editdcopinterface.moc"
namespace KTextEditor
{
@@ -38,7 +38,7 @@ namespace KTextEditor
/**
* Get the current cursor coordinates in pixels.
*/
- class QPoint cursorCoordinates ();
+ class TQPoint cursorCoordinates ();
/**
* Get the cursor position
diff --git a/interfaces/ktexteditor/viewcursorinterface.cpp b/interfaces/ktexteditor/viewcursorinterface.cpp
index 5e9503984..0c834be42 100644
--- a/interfaces/ktexteditor/viewcursorinterface.cpp
+++ b/interfaces/ktexteditor/viewcursorinterface.cpp
@@ -45,7 +45,7 @@ ViewCursorInterface::ViewCursorInterface()
myViewCursorInterfaceNumber = globalViewCursorInterfaceNumber++;
d = new PrivateViewCursorInterface();
- QString name = "ViewCursorInterface#" + QString::number(myViewCursorInterfaceNumber);
+ TQString name = "ViewCursorInterface#" + TQString::number(myViewCursorInterfaceNumber);
d->interface = new ViewCursorDCOPInterface(this, name.latin1());
}
@@ -60,7 +60,7 @@ unsigned int ViewCursorInterface::viewCursorInterfaceNumber () const
return myViewCursorInterfaceNumber;
}
-void ViewCursorInterface::setViewCursorInterfaceDCOPSuffix (const QCString &suffix)
+void ViewCursorInterface::setViewCursorInterfaceDCOPSuffix (const TQCString &suffix)
{
d->interface->setObjId ("ViewCursorInterface#"+suffix);
}
diff --git a/interfaces/ktexteditor/viewcursorinterface.h b/interfaces/ktexteditor/viewcursorinterface.h
index 05a427bae..0264f5177 100644
--- a/interfaces/ktexteditor/viewcursorinterface.h
+++ b/interfaces/ktexteditor/viewcursorinterface.h
@@ -41,7 +41,7 @@ class KTEXTEDITOR_EXPORT ViewCursorInterface
unsigned int viewCursorInterfaceNumber () const;
protected:
- void setViewCursorInterfaceDCOPSuffix (const QCString &suffix);
+ void setViewCursorInterfaceDCOPSuffix (const TQCString &suffix);
//
// slots !!!
@@ -50,7 +50,7 @@ class KTEXTEDITOR_EXPORT ViewCursorInterface
/**
* Get the current cursor coordinates in pixels.
*/
- virtual class QPoint cursorCoordinates () = 0;
+ virtual class TQPoint cursorCoordinates () = 0;
/**
* Get the cursor position
diff --git a/interfaces/ktexteditor/viewstatusmsgdcopinterface.cpp b/interfaces/ktexteditor/viewstatusmsgdcopinterface.cpp
index 4cd2c6c2d..d38b9b938 100644
--- a/interfaces/ktexteditor/viewstatusmsgdcopinterface.cpp
+++ b/interfaces/ktexteditor/viewstatusmsgdcopinterface.cpp
@@ -1,7 +1,7 @@
#include "viewstatusmsgdcopinterface.h"
#include "viewstatusmsginterface.h"
-#include <qstring.h>
+#include <tqstring.h>
#include <dcopclient.h>
using namespace KTextEditor;
@@ -22,7 +22,7 @@ uint ViewStatusMsgDCOPInterface::viewStatusMsgInterfaceNumber ()
return m_parent->viewStatusMsgInterfaceNumber ();
}
-void ViewStatusMsgDCOPInterface::viewStatusMsg (QString msg)
+void ViewStatusMsgDCOPInterface::viewStatusMsg (TQString msg)
{
m_parent->viewStatusMsg(msg);
}
diff --git a/interfaces/ktexteditor/viewstatusmsgdcopinterface.h b/interfaces/ktexteditor/viewstatusmsgdcopinterface.h
index 45d5507d3..b4c5cf72e 100644
--- a/interfaces/ktexteditor/viewstatusmsgdcopinterface.h
+++ b/interfaces/ktexteditor/viewstatusmsgdcopinterface.h
@@ -3,8 +3,8 @@
#include <dcopobject.h>
#include <dcopref.h>
-#include <qstringlist.h>
-#include <qcstring.h>
+#include <tqstringlist.h>
+#include <tqcstring.h>
//#include "editdcopinterface.moc"
namespace KTextEditor
{
@@ -34,7 +34,7 @@ namespace KTextEditor
virtual ~ViewStatusMsgDCOPInterface();
k_dcop:
uint viewStatusMsgInterfaceNumber ();
- void viewStatusMsg (class QString msg) ;
+ void viewStatusMsg (class TQString msg) ;
private:
ViewStatusMsgInterface *m_parent;
diff --git a/interfaces/ktexteditor/viewstatusmsginterface.cpp b/interfaces/ktexteditor/viewstatusmsginterface.cpp
index d519678eb..ff0815c89 100644
--- a/interfaces/ktexteditor/viewstatusmsginterface.cpp
+++ b/interfaces/ktexteditor/viewstatusmsginterface.cpp
@@ -22,7 +22,7 @@
#include "viewstatusmsgdcopinterface.h"
#include "view.h"
-#include <qstring.h>
+#include <tqstring.h>
namespace KTextEditor
{
@@ -47,7 +47,7 @@ ViewStatusMsgInterface::ViewStatusMsgInterface()
myViewStatusMsgInterfaceNumber = globalViewStatusMsgInterfaceNumber++;
d = new PrivateViewStatusMsgInterface();
- ::QString name = "ViewStatusMsgInterface#" + ::QString::number(myViewStatusMsgInterfaceNumber);
+ ::TQString name = "ViewStatusMsgInterface#" + ::TQString::number(myViewStatusMsgInterfaceNumber);
d->interface = new ViewStatusMsgDCOPInterface(this, name.latin1());
}
@@ -62,7 +62,7 @@ unsigned int ViewStatusMsgInterface::viewStatusMsgInterfaceNumber () const
return myViewStatusMsgInterfaceNumber;
}
-void ViewStatusMsgInterface::setViewStatusMsgInterfaceDCOPSuffix (const QCString &suffix)
+void ViewStatusMsgInterface::setViewStatusMsgInterfaceDCOPSuffix (const TQCString &suffix)
{
d->interface->setObjId ("ViewStatusMsgInterface#"+suffix);
}
diff --git a/interfaces/ktexteditor/viewstatusmsginterface.h b/interfaces/ktexteditor/viewstatusmsginterface.h
index 9c49cab1c..667494277 100644
--- a/interfaces/ktexteditor/viewstatusmsginterface.h
+++ b/interfaces/ktexteditor/viewstatusmsginterface.h
@@ -41,13 +41,13 @@ class KTEXTEDITOR_EXPORT ViewStatusMsgInterface
unsigned int viewStatusMsgInterfaceNumber () const;
protected:
- void setViewStatusMsgInterfaceDCOPSuffix (const QCString &suffix);
+ void setViewStatusMsgInterfaceDCOPSuffix (const TQCString &suffix);
//
// signals !!!
//
public:
- virtual void viewStatusMsg (const class QString &msg) = 0;
+ virtual void viewStatusMsg (const class TQString &msg) = 0;
private:
diff --git a/interfaces/ktexteditor/wordwrapinterface.cpp b/interfaces/ktexteditor/wordwrapinterface.cpp
index 9bf01ecff..3afe5c230 100644
--- a/interfaces/ktexteditor/wordwrapinterface.cpp
+++ b/interfaces/ktexteditor/wordwrapinterface.cpp
@@ -56,7 +56,7 @@ unsigned int WordWrapInterface::wordWrapInterfaceNumber () const
return myWordWrapInterfaceNumber;
}
-void WordWrapInterface::setWordWrapInterfaceDCOPSuffix (const QCString &/*suffix*/)
+void WordWrapInterface::setWordWrapInterfaceDCOPSuffix (const TQCString &/*suffix*/)
{
//d->interface->setObjId ("WordWrapInterface#"+suffix);
}
diff --git a/interfaces/ktexteditor/wordwrapinterface.h b/interfaces/ktexteditor/wordwrapinterface.h
index 81fbb2efa..0ececa7f5 100644
--- a/interfaces/ktexteditor/wordwrapinterface.h
+++ b/interfaces/ktexteditor/wordwrapinterface.h
@@ -41,7 +41,7 @@ class KTEXTEDITOR_EXPORT WordWrapInterface
unsigned int wordWrapInterfaceNumber () const;
protected:
- void setWordWrapInterfaceDCOPSuffix (const QCString &suffix);
+ void setWordWrapInterfaceDCOPSuffix (const TQCString &suffix);
//
// slots !!!
diff --git a/interfaces/ktexteditor/selectiondcopinterface.cpp b/interfaces/ktexteditor/selectiondcopinterface.cpp
index c1405ae16..f341297e0 100644
--- a/interfaces/ktexteditor/selectiondcopinterface.cpp
+++ b/interfaces/ktexteditor/selectiondcopinterface.cpp
@@ -40,9 +40,9 @@ SelectionDCOPInterface::~SelectionDCOPInterface()
}
/**
* @return a QString for the selected text
*/
- QString SelectionDCOPInterface::selection ()
+ TQString SelectionDCOPInterface::selection ()
{
return m_parent->selection();
}
@@ -40,9 +40,9 @@ SelectionDCOPInterface::~SelectionDCOPInterface()
}
/**
- * @return a QString for the selected text
+ * @return a TQString for the selected text
*/
diff --git a/interfaces/ktexteditor/selectiondcopinterface.h b/interfaces/ktexteditor/selectiondcopinterface.h
index 87efc1918..aa2973540 100644
--- a/interfaces/ktexteditor/selectiondcopinterface.h
+++ b/interfaces/ktexteditor/selectiondcopinterface.h
@@ -3,8 +3,8 @@
#include <dcopobject.h>
#include <dcopref.h>
-#include <qstringlist.h>
-#include <qcstring.h>
+#include <tqstringlist.h>
+#include <tqcstring.h>
namespace KTextEditor
{
@@ -49,9 +49,9 @@ namespace KTextEditor
bool hasSelection ();
/**
* @return a QString for the selected text
*/
- QString selection ();
+ TQString selection ();
/**
* removes the selected Text
@@ -49,9 +49,9 @@ namespace KTextEditor
bool hasSelection ();
/**
- * @return a QString for the selected text
+ * @return a TQString for the selected text
*/
diff --git a/interfaces/ktexteditor/selectioninterface.h b/interfaces/ktexteditor/selectioninterface.h
index 48931a02b..adcf7d5e2 100644
--- a/interfaces/ktexteditor/selectioninterface.h
+++ b/interfaces/ktexteditor/selectioninterface.h
@@ -20,7 +20,7 @@
#ifndef __ktexteditor_selectioninterface_h__
#define __ktexteditor_selectioninterface_h__
-#include <qstring.h>
+#include <tqstring.h>
#include <kdelibs_export.h>
@@ -41,7 +41,7 @@ class KTEXTEDITOR_EXPORT SelectionInterface
unsigned int selectionInterfaceNumber () const;
protected:
- void setSelectionInterfaceDCOPSuffix (const QCString &suffix);
+ void setSelectionInterfaceDCOPSuffix (const TQCString &suffix);
/*
* slots !!!
@@ -63,9 +63,9 @@ class KTEXTEDITOR_EXPORT SelectionInterface
virtual bool hasSelection () const = 0;
/**
* @return a QString for the selected text
*/
- virtual QString selection () const = 0;
+ virtual TQString selection () const = 0;
/**
* removes the selected Text
@@ -63,9 +63,9 @@ class KTEXTEDITOR_EXPORT SelectionInterface
virtual bool hasSelection () const = 0;
/**
- * @return a QString for the selected text
+ * @return a TQString for the selected text
*/